@@ -21,7 +21,9 @@ extern struct hardware hw_devinput;
 extern struct hardware hw_dsp;
 extern struct hardware hw_dvico;
 extern struct hardware hw_ea65;
+extern struct hardware hw_i2cuser;
 extern struct hardware hw_iguanaIR;
+extern struct hardware hw_irlink;
 extern struct hardware hw_irman;
 extern struct hardware hw_livedrive_midi;
 extern struct hardware hw_livedrive_seq;
@@ -30,9 +32,11 @@ extern struct hardware hw_macmini;
 extern struct hardware hw_mouseremote;
 extern struct hardware hw_mouseremote_ps2;
 extern struct hardware hw_mp3anywhere;
+extern struct hardware hw_mplay;
 extern struct hardware hw_pcmak;
 extern struct hardware hw_pinsys;
 extern struct hardware hw_pixelview;
+extern struct hardware hw_samsung;
 extern struct hardware hw_sb0540;
 extern struct hardware hw_silitek;
 extern struct hardware hw_slinke;
@@ -75,7 +79,9 @@ struct hardware *hw_list[] =
 #ifdef HAVE_ALSA_SB_RC
 	&hw_alsa_usb,
 #endif
+#ifdef HAVE_LINUX_HIDDEV_H
 	&hw_asusdh,
+#endif
 #ifdef HAVE_LIBUSB
 	&hw_atilibusb,
 #endif
@@ -86,7 +92,9 @@ struct hardware *hw_list[] =
 	&hw_audio_alsa,
 #endif
 	&hw_bte,
+#ifdef HAVE_LINUX_HIDDEV_H
 	&hw_bw6130,
+#endif
 	&hw_creative,
 #ifdef HAVE_SCSI
 	&hw_creative_infracd,
@@ -98,25 +106,36 @@ struct hardware *hw_list[] =
 #ifdef HAVE_SOUNDCARD
 	&hw_dsp,
 #endif
+#ifdef HAVE_LINUX_HIDDEV_H
 	&hw_dvico,
+#endif
 	&hw_ea65,
+	&hw_i2cuser,
 #ifdef HAVE_IGUANAIR
 	&hw_iguanaIR,
 #endif
+	&hw_irlink,
 #ifdef HAVE_LIBIRMAN
 	&hw_irman,
 #endif
 	&hw_livedrive_midi,
 	&hw_livedrive_seq,
 	&hw_logitech,
+#ifdef HAVE_LINUX_HIDDEV_H
+	&hw_macmini,
+#endif
 	&hw_mp3anywhere,
+	&hw_mplay,
 	&hw_mouseremote,
 	&hw_mouseremote_ps2,
 	&hw_null,
 	&hw_pcmak,
 	&hw_pinsys,
 	&hw_pixelview,
+#ifdef HAVE_LINUX_HIDDEV_FLAG_UREF
+	&hw_samsung,
 	&hw_sb0540,
+#endif
 	&hw_silitek,
 	/*	&hw_slinke,*/
 	&hw_tira,
@@ -144,6 +163,11 @@ int hw_choose_driver (char *name)
 		hw = HW_DEFAULT;
 		return 0;
 	}
+	if(strcasecmp(name, "dev/input") == 0)
+	{
+		/* backwards compatibility */
+		name = "devinput";
+	}
 	for (i=0; hw_list[i]; i++)
 		if (!strcasecmp (hw_list[i]->name, name))
 			break;
