@@ -1,4 +1,4 @@
-/*      $Id: hw_default.c,v 5.31 2005/07/10 08:34:11 lirc Exp $      */
+/*      $Id: hw_default.c,v 5.36 2008/03/30 14:53:06 lirc Exp $      */
 
 /****************************************************************************
  ** hw_default.c ************************************************************
@@ -75,7 +75,7 @@ struct hardware hw_default=
 	default_deinit,     /* deinit_func */
 	default_send,       /* send_func */
 	default_rec,        /* rec_func */
-	default_decode,     /* decode_func */
+	receive_decode,     /* decode_func */
 	default_ioctl,      /* ioctl_func */
 	default_readdata,
 	"default"
@@ -133,9 +133,10 @@ lirc_t default_readdata(lirc_t timeout)
 	ret=read(hw.fd,&data,sizeof(data));
 	if(ret!=sizeof(data))
 	{
-		LOGPRINTF(1,"error reading from lirc");
-		LOGPERROR(1,NULL);
-		dosigterm(SIGTERM);
+		logprintf(LOG_ERR, "error reading from %s", hw.device);
+		logperror(LOG_ERR, NULL);
+		default_deinit();
+		return 0;
 	}
 #endif
 	return(data);
@@ -227,7 +228,7 @@ int default_init()
 			  "installation");
 		return(0);
 	}
-	else if(ioctl(hw.fd,LIRC_GET_FEATURES,&hw.features)==-1)
+	else if(default_ioctl(LIRC_GET_FEATURES, &hw.features)==-1)
 	{
 		logprintf(LOG_ERR,"could not get hardware features");
 		logprintf(LOG_ERR,"this device driver does not "
@@ -286,7 +287,7 @@ int default_init()
 				unsigned long mode;
 
 				mode=LIRC_SEND2MODE(supported_send_modes[i]);
-				if(ioctl(hw.fd,LIRC_SET_SEND_MODE,&mode)==-1)
+				if(default_ioctl(LIRC_SET_SEND_MODE, &mode)==-1)
 				{
 					logprintf(LOG_ERR,"could not set "
 						  "send mode");
@@ -315,7 +316,7 @@ int default_init()
 				unsigned long mode;
 
 				mode=LIRC_REC2MODE(supported_rec_modes[i]);
-				if(ioctl(hw.fd,LIRC_SET_REC_MODE,&mode)==-1)
+				if(default_ioctl(LIRC_SET_REC_MODE, &mode)==-1)
 				{
 					logprintf(LOG_ERR,"could not set "
 						  "receive mode");
@@ -337,7 +338,8 @@ int default_init()
 	{
 		/* get resolution */
 		hw.resolution=0;
-		if(ioctl(hw.fd, LIRC_GET_REC_RESOLUTION, &hw.resolution)!=-1)
+		if((hw.features&LIRC_CAN_GET_REC_RESOLUTION) &&
+		   (default_ioctl(LIRC_GET_REC_RESOLUTION, &hw.resolution)!=-1))
 		{
 			LOGPRINTF(1, "resolution of receiver: %d",
 				  hw.resolution);
@@ -350,7 +352,7 @@ int default_init()
 	}
 	else if(hw.rec_mode==LIRC_MODE_LIRCCODE)
 	{
-		if(ioctl(hw.fd,LIRC_GET_LENGTH,&hw.code_length)==-1)
+		if(default_ioctl(LIRC_GET_LENGTH, &hw.code_length)==-1)
 		{
 			logprintf(LOG_ERR,"could not get code length");
 			logperror(LOG_ERR,"default_init()");
@@ -391,8 +393,11 @@ int default_config(struct ir_remote *remotes)
 int default_deinit(void)
 {
 #if (!defined(SIM_SEND) || !defined(SIM_SEND)) || defined(DAEMONIZE)
-	close(hw.fd);
-	hw.fd=-1;
+	if(hw.fd != -1)
+	{
+		close(hw.fd);
+		hw.fd=-1;
+	}
 #endif
 	return(1);
 }
@@ -439,7 +444,7 @@ int default_send(struct ir_remote *remote,struct ir_ncode *code)
 		unsigned int freq;
 		
 		freq=remote->freq==0 ? DEFAULT_FREQ:remote->freq;
-		if(ioctl(hw.fd,LIRC_SET_SEND_CARRIER,&freq)==-1)
+		if(default_ioctl(LIRC_SET_SEND_CARRIER, &freq)==-1)
 		{
 			logprintf(LOG_ERR,"could not set modulation "
 				  "frequency");
@@ -452,7 +457,7 @@ int default_send(struct ir_remote *remote,struct ir_ncode *code)
 		unsigned int duty_cycle;
 		
 		duty_cycle=remote->duty_cycle==0 ? 50:remote->duty_cycle;
-		if(ioctl(hw.fd,LIRC_SET_SEND_DUTY_CYCLE,&duty_cycle)==-1)
+		if(default_ioctl(LIRC_SET_SEND_DUTY_CYCLE, &duty_cycle)==-1)
 		{
 			logprintf(LOG_ERR,"could not set duty cycle");
 			logperror(LOG_ERR,NULL);
@@ -460,7 +465,7 @@ int default_send(struct ir_remote *remote,struct ir_ncode *code)
 		}
 	}
 #endif
-	remaining_gap=remote->remaining_gap;
+	remaining_gap=remote->min_remaining_gap;
 	if(!init_send(remote,code)) return(0);
 	
 #if !defined(SIM_SEND) || defined(DAEMONIZE)
@@ -491,10 +496,8 @@ int default_send(struct ir_remote *remote,struct ir_ncode *code)
 	}
 	else
 	{
-		gettimeofday(&remote->last_send,NULL);
-		remote->last_code=code;
 #if defined(SIM_SEND) && !defined(DAEMONIZE)
-		printf("space %lu\n",(unsigned long) remote->remaining_gap);
+		printf("space %lu\n",(unsigned long) remote->min_remaining_gap);
 #endif
 	}
 	return(1);
@@ -540,14 +543,6 @@ char *default_rec(struct ir_remote *remotes)
 	}
 }
 
-int default_decode(struct ir_remote *remote,
-		   ir_code *prep,ir_code *codep,ir_code *postp,
-		   int *repeat_flagp,lirc_t *remaining_gapp)
-{
-	return(receive_decode(remote,prep,codep,postp,
-			      repeat_flagp,remaining_gapp));
-}
-
 static int default_config_frequency()
 {
 	unsigned int freq;
@@ -559,7 +554,7 @@ static int default_config_frequency()
 	if(hw.features&LIRC_CAN_SET_REC_CARRIER_RANGE &&
 	   min_freq!=max_freq)
 	{
-		if(ioctl(hw.fd,LIRC_SET_REC_CARRIER_RANGE,&min_freq)==-1)
+		if(default_ioctl(LIRC_SET_REC_CARRIER_RANGE, &min_freq)==-1)
 		{
 			logprintf(LOG_ERR,"could not set receive carrier");
 			logperror(LOG_ERR,"default_init()");
@@ -571,7 +566,7 @@ static int default_config_frequency()
 	{
 		freq=(min_freq+max_freq)/2;
 	}
-	if(ioctl(hw.fd,LIRC_SET_REC_CARRIER,&freq)==-1)
+	if(default_ioctl(LIRC_SET_REC_CARRIER, &freq)==-1)
 	{
 		logprintf(LOG_ERR,"could not set receive carrier");
 		logperror(LOG_ERR,"default_init()");
@@ -580,7 +575,7 @@ static int default_config_frequency()
 	return(1);
 }
 
-int default_ioctl(unsigned int cmd, unsigned long arg)
+int default_ioctl(unsigned int cmd, void *arg)
 {
-	return ioctl(hw.fd, cmd, &arg);
+	return ioctl(hw.fd, cmd, arg);
 }
