@@ -1,4 +1,4 @@
-/*      $Id: hw_irman.h,v 5.1 1999/09/06 14:56:04 columbus Exp $      */
+/*      $Id: hw_irman.h,v 5.2 2007/07/29 18:20:08 lirc Exp $      */
 
 /****************************************************************************
  ** hw_irman.h **************************************************************
@@ -16,8 +16,10 @@
 #include "drivers/lirc.h"
 
 int irman_decode(struct ir_remote *remote,
-		  ir_code *prep,ir_code *codep,ir_code *postp,
-		  int *repeat_flagp,lirc_t *remaining_gapp);
+		 ir_code *prep,ir_code *codep,ir_code *postp,
+		 int *repeat_flagp,
+		 lirc_t *min_remaining_gapp,
+		 lirc_t *max_remaining_gapp);
 int irman_init(void);
 int irman_deinit(void);
 char *irman_rec(struct ir_remote *remotes);
