@@ -21,7 +21,9 @@ int autodetect(void);
 
 int pinsys_decode(struct ir_remote *remote,
 		  ir_code *prep,ir_code *codep,ir_code *postp,
-		  int *repeat_flagp,lirc_t *remaining_gapp);
+		  int *repeat_flagp,
+		  lirc_t *min_remaining_gapp,
+		  lirc_t *max_remaining_gapp);
 int pinsys_init(void);
 int pinsys_deinit(void);
 char *pinsys_rec(struct ir_remote *remotes);
