@@ -1,4 +1,4 @@
-/*      $Id: irrecord.c,v 5.50 2004/02/05 19:44:50 lirc Exp $      */
+/*      $Id: irrecord.c,v 5.69 2008/02/14 20:42:56 lirc Exp $      */
 
 /****************************************************************************
  ** irrecord.c **************************************************************
@@ -56,8 +56,8 @@ void flushhw(void);
 int resethw(void);
 int waitfordata(unsigned long maxusec);
 int availabledata(void);
-int get_toggle_bit(struct ir_remote *remote);
-void set_toggle_bit(struct ir_remote *remote,ir_code xor);
+int get_toggle_bit_mask(struct ir_remote *remote);
+void set_toggle_bit_mask(struct ir_remote *remote,ir_code xor);
 void get_pre_data(struct ir_remote *remote);
 void get_post_data(struct ir_remote *remote);
 #ifdef DEBUG
@@ -67,6 +67,7 @@ void for_each_remote(struct ir_remote *remotes, remote_func func);
 void remove_pre_data(struct ir_remote *remote);
 void remove_post_data(struct ir_remote *remote);
 void invert_data(struct ir_remote *remote);
+void remove_trail(struct ir_remote *remote);
 #endif
 int get_lengths(struct ir_remote *remote,int force);
 struct lengths *new_length(lirc_t length);
@@ -107,7 +108,7 @@ struct ir_ncode ncode;
 
 lirc_t signals[MAX_SIGNALS];
 
-#define AEPS 100
+#define AEPS (hw.resolution>100 ? hw.resolution:100)
 #define EPS 30
 
 /* some threshold values */
@@ -135,29 +136,32 @@ int daemonized=0;
 
 void logprintf(int prio,char *format_str, ...)
 {
-	time_t current;
-	char *currents;
 	va_list ap;  
 	
-	current=time(&current);
-	currents=ctime(&current);
-	
-	if(lf) fprintf(lf,"%15.15s %s %s: ",currents+4,hostname,progname);
-	if(!daemonized) fprintf(stderr,"%s: ",progname);
-	va_start(ap,format_str);
 	if(lf)
 	{
+		time_t current;
+		char *currents;
+		
+		current=time(&current);
+		currents=ctime(&current);
+		
+		fprintf(lf,"%15.15s %s %s: ",currents+4,hostname,progname);
+		va_start(ap,format_str);
 		if(prio==LOG_WARNING) fprintf(lf,"WARNING: ");
 		vfprintf(lf,format_str,ap);
 		fputc('\n',lf);fflush(lf);
+		va_end(ap);
 	}
 	if(!daemonized)
 	{
+		fprintf(stderr,"%s: ",progname);
+		va_start(ap,format_str);
 		if(prio==LOG_WARNING) fprintf(stderr,"WARNING: ");
 		vfprintf(stderr,format_str,ap);
 		fputc('\n',stderr);fflush(stderr);
+		va_end(ap);
 	}
-	va_end(ap);
 }
 
 void logperror(int prio,const char *s)
@@ -185,13 +189,13 @@ int main(int argc,char **argv)
 	int retval=EXIT_SUCCESS;
 	ir_code pre,code,post;
 	int repeat_flag;
-	lirc_t remaining_gap;
+	lirc_t min_remaining_gap, max_remaining_gap;
 	int force;
 	int retries;
 	struct ir_remote *remotes=NULL;
 	char *device=NULL;
 #ifdef DEBUG
-	int get_pre=0,get_post=0,test=0,invert=0;
+	int get_pre=0,get_post=0,test=0,invert=0,trail=0;
 #endif
 
 	progname=argv[0];
@@ -212,11 +216,12 @@ int main(int argc,char **argv)
 			{"post",no_argument,NULL,'P'},
 			{"test",no_argument,NULL,'t'},
 			{"invert",no_argument,NULL,'i'},
+			{"trail",no_argument,NULL,'T'},
 #endif
 			{0, 0, 0, 0}
 		};
 #ifdef DEBUG
-		c = getopt_long(argc,argv,"hvd:H:fpPti",long_options,NULL);
+		c = getopt_long(argc,argv,"hvd:H:fpPtiT",long_options,NULL);
 #else
 		c = getopt_long(argc,argv,"hvd:H:f",long_options,NULL);
 #endif
@@ -242,6 +247,7 @@ int main(int argc,char **argv)
 				hw_print_drivers(stderr);
 				exit (EXIT_FAILURE);
 			}
+			break;
 		case 'd':
 			device=optarg;
 			break;
@@ -261,6 +267,9 @@ int main(int argc,char **argv)
 		case 'i':
 			invert=1;
 			break;
+		case 'T':
+			trail=1;
+			break;
 #endif
 		default:
 			printf("Try %s -h for help!\n",progname);
@@ -293,6 +302,15 @@ int main(int argc,char **argv)
 	{
 		char *filename_new;
 		
+		if(force)
+		{
+			fprintf(stderr,
+				"%s: file \"%s\" already exists\n"
+				"%s: you cannot use the --force option "
+				"together with a template file\n",
+				progname, filename, progname);
+			exit(EXIT_FAILURE);
+		}
 		remotes=read_config(fin);
 		fclose(fin);
 		if(remotes==(void *) -1 || remotes==NULL)
@@ -305,6 +323,7 @@ int main(int argc,char **argv)
 #ifdef DEBUG
 		if(test)
 		{
+			if(trail) for_each_remote(remotes, remove_trail);
 			for_each_remote(remotes, remove_pre_data);
 			for_each_remote(remotes, remove_post_data);
 			if(get_pre) for_each_remote(remotes, get_pre_data);
@@ -322,12 +341,11 @@ int main(int argc,char **argv)
 		remote.last_code=NULL;
 		remote.next=NULL;
 		remote.toggle_bit=0;
+		remote.toggle_bit_mask=0;
 		if(remote.pre_p==0 && remote.pre_s==0 &&
 		   remote.post_p==0 && remote.post_s==0)
 		{
-			remote.bits=remote.pre_data_bits+
-				remote.bits+
-				remote.post_data_bits;
+			remote.bits=bit_count(&remote);
 			remote.pre_data_bits=0;
 			remote.post_data_bits=0;
 		}
@@ -345,8 +363,9 @@ int main(int argc,char **argv)
 				progname);
 			exit(EXIT_FAILURE);
 		}
-		strcpy(filename_new,filename);
-		strcat(filename,".conf");
+		strcpy(filename_new, filename);
+		strcat(filename_new, ".conf");
+		filename = filename_new;
 	}
 	fout=fopen(filename,"w");
 	if(fout==NULL)
@@ -453,8 +472,7 @@ int main(int argc,char **argv)
 				exit(EXIT_FAILURE);
 			}
 			printf("Creating config file in raw mode.\n");
-			remote.flags&=~(RC5|RC6|RCMM|SPACE_ENC);
-			remote.flags|=RAW_CODES;
+			set_protocol(&remote, RAW_CODES);
 			remote.eps=EPS;
 			remote.aeps=AEPS;
 			break;
@@ -495,7 +513,7 @@ int main(int argc,char **argv)
 		{
 			hw.rec_func(NULL);
 		}
-		if(!get_toggle_bit(&remote))
+		if(!get_toggle_bit_mask(&remote))
 		{
 			printf("But I know for sure that RC6 has a toggle bit!\n");
 			fclose(fout);
@@ -543,7 +561,7 @@ int main(int argc,char **argv)
 			break;
 		}
 		
-		if(remote.flags&RAW_CODES)
+		if(is_raw(&remote))
 		{
 			flushhw();
 		}
@@ -557,7 +575,7 @@ int main(int argc,char **argv)
 		printf("\nNow hold down button \"%s\".\n",buffer);
 		fflush(stdout);
 		
-		if(remote.flags&RAW_CODES)
+		if(is_raw(&remote))
 		{
 			lirc_t data,sum;
 			unsigned int count;
@@ -659,7 +677,9 @@ int main(int argc,char **argv)
 			{
 				hw.rec_func(NULL);
 				if(hw.decode_func(&remote,&pre,&code,&post,
-						  &repeat_flag,&remaining_gap))
+						  &repeat_flag,
+						  &min_remaining_gap,
+						  &max_remaining_gap))
 				{
 					flag=1;
 					break;
@@ -711,7 +731,7 @@ int main(int argc,char **argv)
 		exit(EXIT_FAILURE);
 	}
 	
-	if(remote.flags&RAW_CODES)
+	if(is_raw(&remote))
 	{
 		return(EXIT_SUCCESS);
 	}
@@ -747,14 +767,13 @@ int main(int argc,char **argv)
 		exit(EXIT_FAILURE);
 	}
 	
-	if(remotes->toggle_bit==0)
+	if(!has_toggle_bit_mask(remotes))
 	{
-		get_toggle_bit(remotes);
+		get_toggle_bit_mask(remotes);
 	}
 	else
 	{
-		set_toggle_bit(remotes,
-			       1<<(remotes->bits-remotes->toggle_bit));
+		set_toggle_bit_mask(remotes, remotes->toggle_bit_mask);
 	}
 	if(hw.deinit_func) hw.deinit_func();
 	get_pre_data(remotes);
@@ -785,8 +804,8 @@ void flushhw(void)
 	switch(hw.rec_mode)
 	{
 	case LIRC_MODE_MODE2:
-		size=sizeof(lirc_t);
-		break;
+		while(availabledata()) hw.readdata(0);
+		return;
 	case LIRC_MODE_CODE:
 		size=sizeof(unsigned char);
 		break;
@@ -890,22 +909,30 @@ int availabledata(void)
 	return(0);
 }
 
-int get_toggle_bit(struct ir_remote *remote)
+int get_toggle_bit_mask(struct ir_remote *remote)
 {
 	ir_code pre,code,post;
 	int repeat_flag;
-	lirc_t remaining_gap;
+	lirc_t min_remaining_gap, max_remaining_gap;
 	int retval=EXIT_SUCCESS;
 	int retries,flag,success;
-	ir_code first;
+	ir_code first, last;
 	int seq,repeats;
 	int found;
 	
-	printf("Checking for toggle bit.\n");
+	printf("Checking for toggle bit mask.\n");
 	printf(
-"Please press an arbitrary button repeatedly as fast as possible (don't hold\n"
-"it down!).\n");
-	retries=30;flag=success=0;first=0;
+"Please press an arbitrary button repeatedly as fast as possible.\n"
+"Make sure you keep pressing the SAME button and that you DON'T HOLD\n"
+"the button down!.\n"
+"If you can't see any dots appear, then wait a bit between button presses.\n"
+"\n"
+"Press RETURN to continue."
+);
+	fflush(stdout);
+	getchar();
+
+	retries=30;flag=success=0;first=0;last=0;
 	seq=repeats=0;found=0;
 	while(availabledata())
 	{
@@ -931,10 +958,12 @@ int get_toggle_bit(struct ir_remote *remote)
 				remote->rc6_mask=mask;
 				success=hw.decode_func(remote,&pre,&code,&post,
 						       &repeat_flag,
-						       &remaining_gap);
+						       &min_remaining_gap,
+						       &max_remaining_gap);
 				if(success)
 				{
-					remote->remaining_gap=remaining_gap;
+					remote->min_remaining_gap=min_remaining_gap;
+					remote->max_remaining_gap=max_remaining_gap;
 					break;
 				}
 			}
@@ -943,10 +972,13 @@ int get_toggle_bit(struct ir_remote *remote)
 		else
 		{
 			success=hw.decode_func(remote,&pre,&code,&post,
-					       &repeat_flag,&remaining_gap);
+					       &repeat_flag,
+					       &min_remaining_gap,
+					       &max_remaining_gap);
 			if(success)
 			{
-				remote->remaining_gap=remaining_gap;
+				remote->min_remaining_gap=min_remaining_gap;
+				remote->max_remaining_gap=max_remaining_gap;
 			}
 		}
 		if(success)
@@ -956,15 +988,12 @@ int get_toggle_bit(struct ir_remote *remote)
 				flag=1;
 				first=code;
 			}
-			else if(!repeat_flag)
+			else if(!repeat_flag || code!=last)
 			{
 				seq++;
-				if(!found && (is_rc6(remote) || first^code))
+				if(!found && first^code)
 				{
-					if(!is_rc6(remote))
-					{
-						set_toggle_bit(remote,first^code);
-					}
+					set_toggle_bit_mask(remote,first^code);
 					found=1;
 				}
 				printf(".");fflush(stdout);
@@ -974,6 +1003,7 @@ int get_toggle_bit(struct ir_remote *remote)
 			{
 				repeats++;
 			}
+			last = code;
 		}
 		else
 		{
@@ -982,22 +1012,19 @@ int get_toggle_bit(struct ir_remote *remote)
 	}
 	if(!found)
 	{
-		printf("\nNo toggle bit found.\n");
+		printf("\nNo toggle bit mask found.\n");
 	}
 	else
 	{
-		if(remote->toggle_bit>0)
+		if(remote->toggle_bit_mask>0)
 		{
-			printf("\nToggle bit is %d.\n",remote->toggle_bit);
+			printf("\nToggle bit mask is 0x%llx.\n",
+			       (unsigned long long) remote->toggle_bit_mask);
 		}
 		else if(remote->toggle_mask!=0)
 		{
 			printf("\nToggle mask found.\n");
 		}
-		else
-		{
-			printf("\nInvalid toggle bit.\n");
-		}
 	}
 	if(seq>0) remote->min_repeat=repeats/seq;
 #       ifdef DEBUG
@@ -1006,42 +1033,40 @@ int get_toggle_bit(struct ir_remote *remote)
 	return(found);
 }
 
-void set_toggle_bit(struct ir_remote *remote,ir_code xor)
+void set_toggle_bit_mask(struct ir_remote *remote,ir_code xor)
 {
 	ir_code mask;
-	int toggle_bit;
 	struct ir_ncode *codes;
 	int bits;
 
 	if(!remote->codes) return;
 
-	bits=remote->bits+remote->pre_data_bits+remote->post_data_bits;
+	bits=bit_count(remote);
 	mask=((ir_code) 1)<<(bits-1);
-	toggle_bit=1;
 	while(mask)
 	{
 		if(mask==xor) break;
 		mask=mask>>1;
-		toggle_bit++;
 	}
 	if(mask)
 	{
-		remote->toggle_bit=toggle_bit;
+		remote->toggle_bit_mask = xor;
 		
 		codes=remote->codes;
 		while(codes->name!=NULL)
 		{
-			codes->code&=~mask;
+			codes->code&=~xor;
 			codes++;
 		}
 	}
+	/* Sharp, Denon and some others use a toggle_mask */
+	else if(bits==15 && xor==0x3ff)
+	{
+		remote->toggle_mask=xor;
+	}
 	else
 	{
-		/* Sharp, Denon and some others use a toggle_mask */
-		if(bits==15 && xor==0x3ff)
-		{
-			remote->toggle_mask=xor;
-		}
+		remote->toggle_bit_mask = xor;
 	}
 }
 
@@ -1061,8 +1086,16 @@ void get_pre_data(struct ir_remote *remote)
 	if(codes->name==NULL) return; /* at least 2 codes needed */
 	while(codes->name!=NULL)
 	{
+		struct ir_code_node *loop;
+		
 		mask&=~(last^codes->code);
 		last=codes->code;
+		for(loop=codes->next; loop!=NULL; loop=loop->next)
+		{
+			mask&=~(last^loop->code);
+			last=loop->code;
+		}
+		
 		codes++;
 	}
 	count=0;
@@ -1098,7 +1131,13 @@ void get_pre_data(struct ir_remote *remote)
 		codes=remote->codes;
 		while(codes->name!=NULL)
 		{
+			struct ir_code_node *loop;
+			
 			codes->code&=~mask;
+			for(loop=codes->next; loop!=NULL; loop=loop->next)
+			{
+				loop->code&=~mask;
+			}
 			codes++;
 		}
 	}
@@ -1120,8 +1159,15 @@ void get_post_data(struct ir_remote *remote)
 	if(codes->name==NULL) return; /* at least 2 codes needed */
 	while(codes->name!=NULL)
 	{
+		struct ir_code_node *loop;
+		
 		mask&=~(last^codes->code);
 		last=codes->code;
+		for(loop=codes->next; loop!=NULL; loop=loop->next)
+		{
+			mask&=~(last^loop->code);
+			last=loop->code;
+		}
 		codes++;
 	}
 	count=0;
@@ -1150,7 +1196,13 @@ void get_post_data(struct ir_remote *remote)
 		codes=remote->codes;
 		while(codes->name!=NULL)
 		{
+			struct ir_code_node *loop;
+			
 			codes->code=codes->code>>count;
+			for(loop=codes->next; loop!=NULL; loop=loop->next)
+			{
+				loop->code=loop->code>>count;
+			}
 			codes++;
 		}
 	}
@@ -1183,7 +1235,13 @@ void remove_pre_data(struct ir_remote *remote)
 	codes=remote->codes;
 	while(codes->name!=NULL)
 	{
+		struct ir_code_node *loop;
+		
 		codes->code|=remote->pre_data<<remote->bits;
+		for(loop=codes->next; loop!=NULL; loop=loop->next)
+		{
+			loop->code|=remote->pre_data<<remote->bits;
+		}
 		codes++;
 	}
 	remote->bits+=remote->pre_data_bits;
@@ -1204,8 +1262,15 @@ void remove_post_data(struct ir_remote *remote)
 	codes=remote->codes;
 	while(codes->name!=NULL)
 	{
+		struct ir_code_node *loop;
+		
 		codes->code<<=remote->post_data_bits;
 		codes->code|=remote->post_data;
+		for(loop=codes->next; loop!=NULL; loop=loop->next)
+		{
+			loop->code<<=remote->post_data_bits;
+			loop->code|=remote->post_data;
+		}
 		codes++;
 	}
 	remote->bits+=remote->post_data_bits;
@@ -1251,10 +1316,49 @@ void invert_data(struct ir_remote *remote)
 	codes=remote->codes;
 	while(codes->name!=NULL)
 	{
+		struct ir_code_node *loop;
+		
 		codes->code^=mask;
+		for(loop=codes->next; loop!=NULL; loop=loop->next)
+		{
+			loop->code^=mask;
+		}
 		codes++;
 	}
 }
+
+void remove_trail(struct ir_remote *remote)
+{
+	int extra_bit;
+	
+	if(!is_space_enc(remote)) return;
+	
+	if(remote->ptrail == 0) return;
+	
+	if(expect(remote, remote->pone, remote->pzero) ||
+	   expect(remote, remote->pzero, remote->pone)) return;
+	
+	if(!(expect(remote, remote->sone, remote->szero) &&
+	     expect(remote, remote->szero, remote->sone))) return;
+	
+	if(expect(remote, remote->ptrail, remote->pone))
+	{
+		extra_bit = 1;
+	}
+	else if(expect(remote, remote->ptrail, remote->pzero))
+	{
+		extra_bit = 0;
+	}
+	else
+	{
+		return;
+	}
+	
+	remote->post_data_bits++;
+	remote->post_data<<=1;
+	remote->post_data|=extra_bit;
+	remote->ptrail=0;
+}
 #endif
 
 /* analyse stuff */
@@ -1408,7 +1512,7 @@ int get_lengths(struct ir_remote *remote,int force)
 				/(count_spaces+1);
 				count_spaces++;
 			}
-			if(count>SAMPLES*MAX_SIGNALS)
+			if(count>SAMPLES*MAX_SIGNALS*2)
 			{
 				fprintf(stderr,"\n%s: could not find gap.\n",
 					progname);
@@ -1725,7 +1829,7 @@ void get_scheme(struct ir_remote *remote)
 		/* this is not yet the
 		   number of bits */
 		remote->bits=length;
-		remote->flags|=SPACE_ENC;
+		set_protocol(remote, SPACE_ENC);
 		return;
 	}
 	else
@@ -1764,12 +1868,12 @@ void get_scheme(struct ir_remote *remote)
 				    calc_signal(max2s)<500))
 				{
 					printf("RC-6 remote control found.\n");
-					remote->flags|=RC6;
+					set_protocol(remote, RC6);
 				}
 				else
 				{
 					printf("RC-5 remote control found.\n");
-					remote->flags|=RC5;
+					set_protocol(remote, RC5);
 				}
 				return;
 			}
@@ -1779,7 +1883,7 @@ void get_scheme(struct ir_remote *remote)
 	printf("Suspicious data length: %u.\n",length);
 	/* this is not yet the number of bits */
 	remote->bits=length;
-	remote->flags|=SPACE_ENC;
+	set_protocol(remote, SPACE_ENC);
 }
 
 struct lengths *get_max_length(struct lengths *first,unsigned int *sump)
@@ -1836,7 +1940,7 @@ int get_lead_length(struct ir_remote *remote)
 {
 	unsigned int sum,max_count;
 	struct lengths *first_lead,*max_length,*max2_length;
-	lirc_t a,b;
+	lirc_t a,b,swap;
 	
 	if(!is_biphase(remote)) return(1);
 	if(is_rc6(remote)) return(1);
@@ -1860,7 +1964,10 @@ int get_lead_length(struct ir_remote *remote)
 
 	a=calc_signal(max_length);
 	b=calc_signal(max2_length);
-	if(a>b)	b^=a^=b^=a;
+	if(a>b)
+	{
+		swap=a; a=b; b=swap;
+	}
 	if(abs(2*a-b)<b*EPS/100 || abs(2*a-b)<AEPS)
 	{
 		printf("Found hidden lead pulse: %lu\n",
@@ -2205,7 +2312,7 @@ int get_data_length(struct ir_remote *remote)
 int get_gap_length(struct ir_remote *remote)
 {
 	struct lengths *gaps=NULL;
-	struct timeval start,end,last;
+	struct timeval start,end,last={0,0};
 	int count,flag;
 	struct lengths *scan;
 	int maxcount,lastmaxcount;
