@@ -1,4 +1,4 @@
-/*      $Id: lircd.c,v 5.61 2005/10/30 11:11:46 lirc Exp $      */
+/*      $Id: lircd.c,v 5.76 2008/03/30 14:53:06 lirc Exp $      */
 
 /****************************************************************************
  ** lircd.c *****************************************************************
@@ -38,6 +38,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
+#include <ctype.h>
 #include <string.h>
 #include <signal.h>
 #include <unistd.h>
@@ -56,6 +57,10 @@
 #include <fcntl.h>
 #include <sys/file.h>
 
+#if defined __APPLE__
+#include <sys/ioccom.h>
+#endif
+
 #ifndef timersub
 #define timersub(a, b, result)                                            \
   do {                                                                    \
@@ -73,6 +78,7 @@
 #include "config_file.h"
 #include "hardware.h"
 #include "hw-types.h"
+#include "release.h"
 
 struct ir_remote *remotes;
 struct ir_remote *free_remotes=NULL;
@@ -106,6 +112,7 @@ struct protocol_directive directives[] =
 	{"SEND_STOP",send_stop},
 	{"VERSION",version},
 	{"SET_TRANSMITTERS",set_transmitters},
+	{"SIMULATE",simulate},
 	{NULL,NULL}
 	/*
 	{"DEBUG",debug},
@@ -132,6 +139,9 @@ char *protocol_string[] =
 	"SIGHUP\n"
 };
 
+static void log_enable(int enabled);
+static int log_enabled = 1;
+
 #ifndef USE_SYSLOG
 #define HOSTNAME_LEN 128
 char hostname[HOSTNAME_LEN+1];
@@ -139,16 +149,18 @@ char hostname[HOSTNAME_LEN+1];
 FILE *lf=NULL;
 #endif
 
-/* fixme: */
+/* quite arbitrary limits */
 #define MAX_PEERS	100
+/* substract one for lirc, sockfd, sockinet, logfile, pidfile */
+#define MAX_CLIENTS     (FD_SETSIZE-5-MAX_PEERS)
 
 int sockfd, sockinet;
-int clis[FD_SETSIZE-5-MAX_PEERS]; /* substract one for lirc, sockfd, sockinet, logfile, pidfile */
+int clis[MAX_CLIENTS];
 
 #define CT_LOCAL  1
 #define CT_REMOTE 2
 
-int cli_type[FD_SETSIZE-5-MAX_PEERS];
+int cli_type[MAX_CLIENTS];
 int clin=0;
 
 int listen_tcpip=0;
@@ -159,6 +171,7 @@ int	peern = 0;
 
 int debug=0;
 int daemonized=0;
+int allow_simulate=0;
 
 static sig_atomic_t term=0,hup=0,alrm=0;
 static int termsig;
@@ -196,7 +209,7 @@ oatoi (s)
 /* A safer write(), since sockets might not write all but only some of the
    bytes requested */
 
-inline int write_socket(int fd, char *buf, int len)
+inline int write_socket(int fd, const char *buf, int len)
 {
 	int done,todo=len;
 
@@ -217,7 +230,7 @@ inline int write_socket(int fd, char *buf, int len)
 	return(len);
 }
 
-inline int write_socket_len(int fd, char *buf)
+inline int write_socket_len(int fd, const char *buf)
 {
 	int len;
 
@@ -347,7 +360,7 @@ void dosighup(int sig)
 	if(-1==fchmod(fileno(lf),s.st_mode))
 	{
 		logprintf(LOG_WARNING,"could not set file permissions");
-		logperror(0,NULL);
+		logperror(LOG_WARNING,NULL);
 	}
 #endif
 
@@ -454,7 +467,7 @@ void remove_client(int fd)
 void add_client(int sock)
 {
 	int fd;
-	int clilen;
+	socklen_t clilen;
 	struct sockaddr client_addr;
 	int flags;
 
@@ -467,7 +480,7 @@ void add_client(int sock)
 		dosigterm(SIGTERM);
 	};
 
-	if(fd>=FD_SETSIZE)
+	if(fd>=FD_SETSIZE || clin>=MAX_CLIENTS)
 	{
 		logprintf(LOG_ERR,"connection rejected");
 		shutdown(fd,2);
@@ -855,36 +868,67 @@ void start_server(mode_t permission,int nodaemon)
 	exit(EXIT_FAILURE);
 }
 
-#ifndef USE_SYSLOG
+void log_enable(int enabled)
+{
+	log_enabled = enabled;
+}
+
+#ifdef USE_SYSLOG
 void logprintf(int prio,char *format_str, ...)
 {
-	time_t current;
-	char *currents;
-	va_list ap;  
+	va_list ap;
 	
-	current=time(&current);
-	currents=ctime(&current);
+	if(!log_enabled) return;
 	
-	if(lf) fprintf(lf,"%15.15s %s %s: ",currents+4,hostname,progname);
-	if(!daemonized) fprintf(stderr,"%s: ",progname);
 	va_start(ap,format_str);
-	if(lf)
-	{
-		if(prio==LOG_WARNING) fprintf(lf,"WARNING: ");
-		vfprintf(lf,format_str,ap);
-		fputc('\n',lf);fflush(lf);
-	}
-	if(!daemonized)
-	{
-		if(prio==LOG_WARNING) fprintf(stderr,"WARNING: ");
-		vfprintf(stderr,format_str,ap);
-		fputc('\n',stderr);fflush(stderr);
-	}
+	vsyslog(prio, format_str, ap);
 	va_end(ap);
 }
 
 void logperror(int prio,const char *s)
 {
+	if(!log_enabled) return;
+	
+	if((s)!=NULL) syslog(prio,"%s: %m\n",(char *) s);
+	else syslog(prio,"%m\n");
+}
+#else
+void logprintf(int prio,char *format_str, ...)
+{
+	va_list ap;  
+	
+	if(!log_enabled) return;
+	
+	if(lf)
+	{
+		time_t current;
+		char *currents;
+		
+		current=time(&current);
+		currents=ctime(&current);
+		
+		fprintf(lf,"%15.15s %s %s: ",currents+4,hostname,progname);
+		va_start(ap,format_str);
+		if(prio==LOG_WARNING) fprintf(lf,"WARNING: ");
+		vfprintf(lf,format_str,ap);
+		fputc('\n',lf);fflush(lf);
+		va_end(ap);
+	}
+	if(!daemonized)
+	{
+		fprintf(stderr,"%s: ",progname);
+		va_start(ap,format_str);
+		if(prio==LOG_WARNING) fprintf(stderr,"WARNING: ");
+		vfprintf(stderr,format_str,ap);
+		fputc('\n',stderr);fflush(stderr);
+		va_end(ap);
+	}
+}
+
+void logperror(int prio,const char *s)
+{
+	if(!log_enabled) return;
+	
 	if(s!=NULL)
 	{
 		logprintf(prio,"%s: %s",s,strerror(errno));
@@ -930,6 +974,11 @@ void dosigalrm(int sig)
 		/* we received a different code from the original
 		   remote control we could repeat the wrong code so
 		   better stop repeating */
+		if(repeat_fd != -1)
+		{
+			send_error(repeat_fd, repeat_message, "repeating interrupted\n");
+		}
+		
 		repeat_remote=NULL;
 		repeat_code=NULL;
 		repeat_fd=-1;
@@ -944,12 +993,15 @@ void dosigalrm(int sig)
 		}
 		return;
 	}
-	repeat_remote->repeat_countdown--;
-	if(hw.send_func(repeat_remote,repeat_code) &&
+	if(repeat_code->next == NULL || (repeat_code->transmit_state != NULL && repeat_code->transmit_state->next == NULL))
+	{
+		repeat_remote->repeat_countdown--;
+	}
+	if(send_ir_ncode(repeat_remote,repeat_code) &&
 	   repeat_remote->repeat_countdown>0)
 	{
 		repeat_timer.it_value.tv_sec=0;
-		repeat_timer.it_value.tv_usec=repeat_remote->remaining_gap;
+		repeat_timer.it_value.tv_usec=repeat_remote->min_remaining_gap;
 		repeat_timer.it_interval.tv_sec=0;
 		repeat_timer.it_interval.tv_usec=0;
 		
@@ -990,7 +1042,7 @@ int parse_rc(int fd,char *message,char *arguments,struct ir_remote **remote,
 	}
 	command=strtok(NULL,WHITE_SPACE);
 	if(command==NULL) return(1);
-	*code=get_ir_code(*remote,command);
+	*code=get_code_by_name(*remote,command);
 	if(*code==NULL)
 	{
 		return(send_error(fd,message,"unknown command: \"%s\"\n",
@@ -1244,7 +1296,7 @@ int set_transmitters(int fd,char *message,char *arguments)
 	{
 		next_tx_int=-1;
 		next_tx_int = strtoul(next_arg,&end_ptr,10);
-		if(*end_ptr || (next_tx_int == ULONG_MAX && errno == ERANGE))
+		if(*end_ptr || next_tx_int == 0 || (next_tx_int == ULONG_MAX && errno == ERANGE))
 		{
 			return(send_error(fd,message, "invalid argument\n"));
 		}
@@ -1258,7 +1310,7 @@ int set_transmitters(int fd,char *message,char *arguments)
 		channels |= next_tx_hex;
 	}while ((next_arg=strtok(NULL,WHITE_SPACE))!=NULL);
 	
-	retval = hw.ioctl_func(LIRC_SET_TRANSMITTER_MASK, channels);
+	retval = hw.ioctl_func(LIRC_SET_TRANSMITTER_MASK, &channels);
 	if(retval<0)
 	{
 		return(send_error(fd, message, "error - could not set "
@@ -1275,6 +1327,68 @@ string_error:
 	return(send_error(fd,message,"no arguments given\n"));
 }
 
+int simulate(int fd,char *message,char *arguments)
+{
+	int i;
+	char *sim, *s, *space;
+	
+	if(!allow_simulate)
+	{
+		return send_error(fd, message,
+				  "SIMULATE command is disabled\n");
+	}
+	if(arguments==NULL)
+	{
+		return send_error(fd, message, "no arguments given\n");
+	}
+	
+	s=arguments;
+	for(i=0; i<16; i++, s++)
+	{
+		if(!isxdigit(*s)) goto simulate_invalid_event;
+	}
+	if(*s != ' ')
+	{
+		goto simulate_invalid_event;
+	}
+	s++;
+	if(*s == ' ')
+	{
+		goto simulate_invalid_event;
+	}
+	for(; *s != ' '; s++)
+	{
+		if(!isxdigit(*s)) goto simulate_invalid_event;
+	}
+	s++;
+	space = strchr(s, ' ');
+	if(space == NULL || space == s)
+	{
+		goto simulate_invalid_event;
+	}
+	s = space + 1;
+	space = strchr(s, ' ');
+	if(strlen(s) == 0 || space != NULL)
+	{
+		goto simulate_invalid_event;
+	}
+	
+	sim = malloc(strlen(arguments) + 1 + 1);
+	if(sim == NULL)
+	{
+		return send_error(fd, message, "out of memory\n");
+	}
+	strcpy(sim, arguments);
+	strcat(sim, "\n");
+	broadcast_message(sim);
+	free(sim);
+	
+	return(send_success(fd,message));
+ simulate_invalid_event:
+	return send_error(fd, message, "invalid event\n");
+	
+}
+
 int send_once(int fd,char *message,char *arguments)
 {
 	return(send_core(fd,message,arguments,1));
@@ -1317,13 +1431,18 @@ int send_core(int fd,char *message,char *arguments,int once)
 	{
 		remote->toggle_mask_state=0;
 	}
-	if(remote->toggle_bit>0)
-		remote->repeat_state=
-		!remote->repeat_state;
-	if(!hw.send_func(remote,code))
+	if(has_toggle_bit_mask(remote))
+	{
+		remote->toggle_bit_mask_state =
+			(remote->toggle_bit_mask_state^remote->toggle_bit_mask);
+	}
+	code->transmit_state = NULL;
+	if(!send_ir_ncode(remote,code))
 	{
 		return(send_error(fd,message,"transmission failed\n"));
 	}
+	gettimeofday(&remote->last_send,NULL);
+	remote->last_code = code;
 	if(once)
 	{
 		remote->repeat_countdown=max(remote->repeat_countdown,reps);
@@ -1333,13 +1452,13 @@ int send_core(int fd,char *message,char *arguments,int once)
 		/* you've been warned, now we have a limit */
 		remote->repeat_countdown=REPEAT_MAX;
 	}
-	if(remote->repeat_countdown>0)
+	if(remote->repeat_countdown>0 || code->next != NULL)
 	{
 		repeat_remote=remote;
 		repeat_code=code;
 		repeat_timer.it_value.tv_sec=0;
 		repeat_timer.it_value.tv_usec=
-			remote->remaining_gap;
+			remote->min_remaining_gap;
 		repeat_timer.it_interval.tv_sec=0;
 		repeat_timer.it_interval.tv_usec=0;
 		if(once)
@@ -1517,32 +1636,41 @@ void free_old_remotes()
 {
 	struct ir_remote *scan_remotes,*found;
 	struct ir_ncode *code;
-
+	const char *release_event;
+	
+	if(decoding ==free_remotes) return;
+	
+	release_event = release_map_remotes(free_remotes, remotes);
+	if(release_event != NULL)
+	{
+		broadcast_message(release_event);
+	}
 	if(last_remote!=NULL)
 	{
-		scan_remotes=free_remotes;
-		while(scan_remotes!=NULL)
+		if(is_in_remotes(free_remotes, last_remote))
 		{
-			if(last_remote==scan_remotes)
+			logprintf(LOG_INFO, "last_remote found");
+			found=get_ir_remote(remotes,last_remote->name);
+			if(found!=NULL)
 			{
-				found=get_ir_remote(remotes,last_remote->name);
-				if(found!=NULL)
+				code=get_code_by_name(found,last_remote->last_code->name);
+				if(code!=NULL)
 				{
-					code=get_ir_code(found,last_remote->last_code->name);
-					if(code!=NULL)
-					{
-						found->reps=last_remote->reps;
-						found->repeat_state=last_remote->repeat_state;
-						found->remaining_gap=last_remote->remaining_gap;
-						last_remote=found;
-						last_remote->last_code=code;
-					}
+					found->reps=last_remote->reps;
+					found->toggle_bit_mask_state=last_remote->toggle_bit_mask_state;
+					found->min_remaining_gap=last_remote->min_remaining_gap;
+					found->max_remaining_gap=last_remote->max_remaining_gap;
+					found->last_send=last_remote->last_send;
+					last_remote=found;
+					last_remote->last_code=code;
+					logprintf(LOG_INFO, "mapped last_remote");
 				}
-				break;
 			}
-			scan_remotes=scan_remotes->next;
 		}
-		if(scan_remotes==NULL) last_remote=NULL;
+		else
+		{
+			last_remote=NULL;
+		}
 	}
 	/* check if last config is still needed */
 	found=NULL;
@@ -1563,7 +1691,7 @@ void free_old_remotes()
 			found=get_ir_remote(remotes,repeat_remote->name);
 			if(found!=NULL)
 			{
-				code=get_ir_code(found,repeat_code->name);
+				code=get_code_by_name(found,repeat_code->name);
 				if(code!=NULL)
 				{
 					struct itimerval repeat_timer;
@@ -1575,8 +1703,9 @@ void free_old_remotes()
 
 					found->last_code=code;
 					found->last_send=repeat_remote->last_send;
-					found->repeat_state=repeat_remote->repeat_state;
-					found->remaining_gap=repeat_remote->remaining_gap;
+					found->toggle_bit_mask_state=repeat_remote->toggle_bit_mask_state;
+					found->min_remaining_gap=repeat_remote->min_remaining_gap;
+					found->max_remaining_gap=repeat_remote->max_remaining_gap;
 
 					setitimer(ITIMER_REAL,&repeat_timer,&repeat_timer);
 					/* "atomic" (shouldn't be necessary any more) */
@@ -1604,12 +1733,35 @@ void free_old_remotes()
 	}
 }
 
+void broadcast_message(const char *message)
+{
+	int len,i;
+	const char *release_message;
+
+	release_message = check_release_event();
+	if(release_message)
+	{
+		broadcast_message(release_message);
+	}
+
+	len=strlen(message);
+			
+	for (i=0; i<clin; i++)
+	{
+		LOGPRINTF(1,"writing to client %d",i);
+		if(write_socket(clis[i],message,len)<len)
+		{
+			remove_client(clis[i]);
+			i--;
+		}			
+	}
+}
 
 int waitfordata(long maxusec)
 {
 	fd_set fds;
 	int maxfd,i,ret,reconnect;
-	struct timeval tv,start,now;
+	struct timeval tv,start,now,timeout,release_time;
 
 	while(1)
 	{
@@ -1639,7 +1791,7 @@ int waitfordata(long maxusec)
 				FD_SET(sockinet,&fds);
 				maxfd=max(maxfd,sockinet);
 			}
-			if(clin>0 && hw.rec_mode!=0)
+			if(clin>0 && hw.rec_mode!=0 && hw.fd!=-1)
 			{
 				FD_SET(hw.fd,&fds);
 				maxfd=max(maxfd,hw.fd);
@@ -1699,10 +1851,42 @@ int waitfordata(long maxusec)
 				tv.tv_sec= maxusec / 1000000;
 				tv.tv_usec=maxusec % 1000000;
 			}
+			if(hw.fd == -1)
+			{
+				/* try to reconnect */
+				timerclear(&timeout);
+				timeout.tv_sec = 1;
+				
+				if(timercmp(&tv, &timeout, >) ||
+				   (!reconnect && !timerisset(&tv)))
+				{
+					tv = timeout;
+				}
+			}
+			get_release_time(&release_time);
+			if(timerisset(&release_time))
+			{
+				gettimeofday(&now,NULL);
+				if(timercmp(&now,&release_time,>))
+				{
+					timerclear(&tv);
+				}
+				else
+				{
+					struct timeval gap;
+					
+					timersub(&release_time, &now, &gap);
+					if(timercmp(&tv, &gap, >))
+					{
+						tv = gap;
+					}
+				}
+			}
 #ifdef SIM_REC
 			ret=select(maxfd+1,&fds,NULL,NULL,NULL);
 #else
-			if(timerisset(&tv) || reconnect)
+			if(timerisset(&tv) || timerisset(&release_time) ||
+			   reconnect)
 			{
 				ret=select(maxfd+1,&fds,NULL,NULL,&tv);
 			}
@@ -1719,6 +1903,16 @@ int waitfordata(long maxusec)
 				continue;
 			}
 			gettimeofday(&now,NULL);
+			if(timerisset(&release_time) &&
+			   timercmp(&now, &release_time, >))
+			{
+				const char *release_message;
+				release_message = trigger_release_event();
+				if(release_message)
+				{
+					broadcast_message(release_message);
+				}
+			}
 			if(free_remotes!=NULL)
 			{
 				free_old_remotes();
@@ -1746,6 +1940,12 @@ int waitfordata(long maxusec)
 		}
 		while(ret==-1 && errno==EINTR);
 		
+		if(hw.fd == -1 && clin > 0 && hw.init_func)
+		{
+			log_enable(0);
+			hw.init_func();
+			log_enable(1);
+		}
 		for(i=0;i<clin;i++)
 		{
 			if(FD_ISSET(clis[i],&fds))
@@ -1785,8 +1985,10 @@ int waitfordata(long maxusec)
 			LOGPRINTF(1,"registering inet client");
 			add_client(sockinet);
 		}
-                if(clin>0 && hw.rec_mode!=0 && FD_ISSET(hw.fd,&fds))
+                if(clin>0 && hw.rec_mode!=0 && hw.fd!=-1 &&
+		   FD_ISSET(hw.fd,&fds))
                 {
+			register_input();
                         /* we will read later */
 			return(1);
                 }
@@ -1796,7 +1998,6 @@ int waitfordata(long maxusec)
 void loop()
 {
 	char *message;
-	int len,i;
 	
 	logprintf(LOG_NOTICE,"lircd(%s) ready",LIRC_DRIVER);
 	while(1)
@@ -1807,17 +2008,13 @@ void loop()
 		
 		if(message!=NULL)
 		{
-			len=strlen(message);
-			
-			for (i=0; i<clin; i++)
+			if(hw.ioctl_func &&
+			   (hw.features&LIRC_CAN_NOTIFY_DECODE))
 			{
-				LOGPRINTF(1,"writing to client %d",i);
-				if(write_socket(clis[i],message,len)<len)
-				{
-					remove_client(clis[i]);
-					i--;
-				}			
+				hw.ioctl_func(LIRC_NOTIFY_DECODE, NULL);
 			}
+			
+			broadcast_message(message);
 		}
 	}
 }
@@ -1851,9 +2048,11 @@ int main(int argc,char **argv)
 #                       ifdef DEBUG
 			{"debug",optional_argument,NULL,'D'},
 #                       endif
+			{"release",optional_argument,NULL,'r'},
+			{"allow-simulate",no_argument,NULL,'a'},
 			{0, 0, 0, 0}
 		};
-		c = getopt_long(argc,argv,"hvnp:H:d:o:P:l::c:"
+		c = getopt_long(argc,argv,"hvnp:H:d:o:P:l::c:r::a"
 #                               ifndef USE_SYSLOG
 				"L:"
 #                               endif
@@ -1883,6 +2082,8 @@ int main(int argc,char **argv)
 #                       ifdef DEBUG
 			printf("\t -D[debug_level] --debug[=debug_level]\n");
 #                       endif
+			printf("\t -r --release[=suffix]\t\tauto-generate release events\n");
+			printf("\t -a --allow-simulate\t\taccept SIMULATE command\n");
 			return(EXIT_SUCCESS);
 		case 'v':
 			printf("%s %s\n",progname,VERSION);
@@ -1956,6 +2157,19 @@ int main(int argc,char **argv)
 			}
 			break;
 #               endif
+		case 'r':
+			if(optarg)
+			{
+				set_release_suffix(optarg);
+			}
+			else
+			{
+				set_release_suffix(LIRC_RELEASE_SUFFIX);
+			}
+			break;
+		case 'a':
+			allow_simulate=1;
+			break;
 		default:
 			printf("Usage: %s [options] [config-file]\n",progname);
 			return(EXIT_FAILURE);
@@ -2037,13 +2251,14 @@ int main(int argc,char **argv)
 			{
 				repeat_remote=NULL;
 				repeat_code=NULL;
-				hw.send_func(r,c);
+				c->transmit_state = NULL;
+				send_ir_ncode(r,c);
 				repeat_remote=r;
 				repeat_code=c;
-				hw.send_func(r,c);
-				hw.send_func(r,c);
-				hw.send_func(r,c);
-				hw.send_func(r,c);
+				send_ir_ncode(r,c);
+				send_ir_ncode(r,c);
+				send_ir_ncode(r,c);
+				send_ir_ncode(r,c);
 				c++;
 			}
 			r=r->next;
