@@ -1,13 +1,16 @@
-/*      $Id: lirc.h,v 5.10 2005/07/10 08:34:12 lirc Exp $      */
+/*      $Id: lirc.h,v 5.14 2008/01/12 21:57:57 lirc Exp $      */
 
 #ifndef _LINUX_LIRC_H
 #define _LINUX_LIRC_H
 
-#if defined (__linux__)
+#if defined(__linux__)
 #include <asm/types.h>
 #include <linux/ioctl.h>
 #else
 #include <sys/types.h>
+#if defined(__NetBSD__)
+#include <sys/ioctl.h>
+#endif
 typedef u_int32_t __u32;
 #endif
 
@@ -61,11 +64,13 @@ typedef int lirc_t;
 
 #define LIRC_CAN_SET_REC_DUTY_CYCLE_RANGE 0x40000000
 #define LIRC_CAN_SET_REC_CARRIER_RANGE    0x80000000
-
+#define LIRC_CAN_GET_REC_RESOLUTION       0x20000000
 
 #define LIRC_CAN_SEND(x) ((x)&LIRC_CAN_SEND_MASK)
 #define LIRC_CAN_REC(x) ((x)&LIRC_CAN_REC_MASK)
 
+#define LIRC_CAN_NOTIFY_DECODE            0x01000000
+
 /*
  * IOCTL commands for lirc driver
  */
@@ -100,4 +105,6 @@ typedef int lirc_t;
 #define LIRC_SET_REC_DUTY_CYCLE_RANGE  _IOW('i', 0x0000001e, __u32)
 #define LIRC_SET_REC_CARRIER_RANGE     _IOW('i', 0x0000001f, __u32)
 
+#define LIRC_NOTIFY_DECODE             _IO('i', 0x00000020)
+
 #endif
