@@ -23,25 +23,25 @@
  * portions of that code have been removed as the driver has evolved.
  *
  * 2003_11_11 - Restructured to minimalize code interpretation in the
- *              driver. The normal use case will be with lirc.
+ *	      driver. The normal use case will be with lirc.
  *
  * 2004_01_01 - Removed all code interpretation. Generate mode2 data
- *              for passing off to lirc. Cleanup
+ *	      for passing off to lirc. Cleanup
  *
  * 2004_01_04 - Removed devfs handle. Put in a temporary workaround
- *              for a known issue where repeats generate two
- *              sequential spaces (last_was_repeat_gap)
+ *	      for a known issue where repeats generate two
+ *	      sequential spaces (last_was_repeat_gap)
  *
  * 2004_02_17 - Changed top level api to no longer use fops, and
- *              instead use new interface for polling via
- *              lirc_thread. Restructure data read/mode2 generation to
- *              a single pass, reducing number of buffers. Rev to .2
+ *	      instead use new interface for polling via
+ *	      lirc_thread. Restructure data read/mode2 generation to
+ *	      a single pass, reducing number of buffers. Rev to .2
  *
  * 2004_02_27 - Last of fixups to plugin->add_to_buf API. Properly
- *              handle broken fragments from the receiver. Up the
- *              sample rate and remove any pacing from
- *              fetch_more_data. Fixes all known issues.
- * 
+ *	      handle broken fragments from the receiver. Up the
+ *	      sample rate and remove any pacing from
+ *	      fetch_more_data. Fixes all known issues.
+ *
  * TODO
  *   - Fix up minor number, registration of major/minor with usb subsystem
  *
@@ -88,7 +88,7 @@
  *
  */
 
-#include <linux/config.h>
+#include <linux/autoconf.h>
 #include <linux/kernel.h>
 #include <linux/errno.h>
 #include <linux/init.h>
@@ -98,8 +98,12 @@
 #include <linux/usb.h>
 #ifdef KERNEL_2_5
 #include <linux/completion.h>
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 19)
 #include <asm/uaccess.h>
 #else
+#include <linux/uaccess.h>
+#endif
+#else
 #include <linux/spinlock.h>
 #include <linux/list.h>
 #include <linux/fcntl.h>
@@ -109,9 +113,9 @@
 #endif
 
 #ifdef CONFIG_USB_DEBUG
-	static int debug = 1;
+static int debug = 1;
 #else
-	static int debug = 0;
+static int debug;
 #endif
 
 #include "drivers/kcompat.h"
@@ -119,11 +123,12 @@
 #include "drivers/lirc_dev/lirc_dev.h"
 
 /* Use our own dbg macro */
-#define dprintk(fmt, args...)                             \
-	do{                                               \
-		if(debug) printk(KERN_DEBUG __FILE__ ": " \
-				 fmt "\n", ## args);      \
-	}while(0)
+#define dprintk(fmt, args...)				\
+	do {						\
+		if (debug)				\
+			printk(KERN_DEBUG __FILE__ ": "	\
+			       fmt "\n", ## args);	\
+	} while (0)
 
 /* Version Information */
 #define DRIVER_VERSION "v0.2"
@@ -136,9 +141,9 @@
 #define USB_MCEUSB_PRODUCT_ID	0x006d
 
 /* table of devices that work with this driver */
-static struct usb_device_id mceusb_table [] = {
+static struct usb_device_id mceusb_table[] = {
 	{ USB_DEVICE(USB_MCEUSB_VENDOR_ID, USB_MCEUSB_PRODUCT_ID) },
-	{ }					/* Terminating entry */
+	{ }	/* Terminating entry */
 };
 
 /* we can have up to this number of device plugged in at once */
@@ -146,46 +151,45 @@ static struct usb_device_id mceusb_table [] = {
 
 /* Structure to hold all of our device specific stuff */
 struct usb_skel {
-	struct usb_device *	    udev;		/* save off the usb device pointer */
-	struct usb_interface *	interface;		/* the interface for this device */
-	unsigned char   minor;				/* the starting minor number for this device */
-	unsigned char   num_ports;			/* the number of ports this device has */
-	char            num_interrupt_in;		/* number of interrupt in endpoints we have */
-	char            num_bulk_in;			/* number of bulk in endpoints we have */
-	char            num_bulk_out;			/* number of bulk out endpoints we have */
+	struct usb_device *udev; /* save off the usb device pointer */
+	struct usb_interface *interface; /* the interface for this device */
+	unsigned char minor;	 /* the starting minor number for this device */
+	unsigned char num_ports; /* the number of ports this device has */
+	char num_interrupt_in;	 /* number of interrupt in endpoints */
+	char num_bulk_in;	 /* number of bulk in endpoints */
+	char num_bulk_out;	 /* number of bulk out endpoints */
 
-	unsigned char *    bulk_in_buffer;		/* the buffer to receive data */
-	int                bulk_in_size;		/* the size of the receive buffer */
-	__u8               bulk_in_endpointAddr;	/* the address of the bulk in endpoint */
+	unsigned char *bulk_in_buffer;	/* the buffer to receive data */
+	int bulk_in_size;		/* the size of the receive buffer */
+	__u8 bulk_in_endpointAddr;	/* the address of bulk in endpoint */
 
-	unsigned char *    bulk_out_buffer;		/* the buffer to send data */
-	int	               bulk_out_size;		/* the size of the send buffer */
-	struct urb *       write_urb;			/* the urb used to send data */
-	__u8               bulk_out_endpointAddr;	/* the address of the bulk out endpoint */
+	unsigned char *bulk_out_buffer;	/* the buffer to send data */
+	int bulk_out_size;		/* the size of the send buffer */
+	struct urb *write_urb;		/* the urb used to send data */
+	__u8 bulk_out_endpointAddr;	/* the address of bulk out endpoint */
 
-	atomic_t		write_busy;		/* true iff write urb is busy */
-	struct completion	write_finished;		/* wait for the write to finish */
-	
-	wait_queue_head_t  wait_q;			/* for timeouts */
-	int                open_count;			/* number of times this port has been opened */
-	struct semaphore   sem;				/* locks this structure */
-	
-	int			present;		/* if the device is not disconnected */		
+	atomic_t write_busy;		/* true iff write urb is busy */
+	struct completion write_finished; /* wait for the write to finish */
+
+	wait_queue_head_t wait_q; /* for timeouts */
+	int open_count;		/* number of times this port has been opened */
+	struct semaphore sem;	/* locks this structure */
+
+	int present;		/* if the device is not disconnected */
+
+	struct lirc_plugin *plugin;
+
+	lirc_t lircdata[256]; /* place to store data until lirc processes it */
+	int lircidx;		/* current index */
+	int lirccnt;		/* remaining values */
+
+	int usb_valid_bytes_in_bulk_buffer; /* leftover data from prior read */
+	int mce_bytes_left_in_packet;	/* for packets split across reads */
 
-	struct lirc_plugin* plugin;
-	
-	lirc_t lircdata[256];          			/* place to store values until lirc processes them */
-	int    lircidx;                			/* current index */
-	int    lirccnt;                			/* remaining values */
-	
-	int    usb_valid_bytes_in_bulk_buffer;		/* leftover data from a previous read */
-	int    mce_bytes_left_in_packet;		/* for packets split across multiple reads */
-	
 	/* Value to hold the last received space; 0 if last value
-	 * received was a pulse
-	 */
-	int    last_space;
-	
+	 * received was a pulse */
+	int last_space;
+
 #ifdef KERNEL_2_5
 	dma_addr_t dma_in;
 	dma_addr_t dma_out;
@@ -196,113 +200,120 @@ struct usb_skel {
 
 /* driver api */
 #ifdef KERNEL_2_5
-static int mceusb_probe		(struct usb_interface *interface, const struct usb_device_id *id);
-static void mceusb_disconnect	(struct usb_interface *interface);
-static void mceusb_write_bulk_callback	(struct urb *urb, struct pt_regs *regs);
+static int mceusb_probe(struct usb_interface *interface,
+			const struct usb_device_id *id);
+static void mceusb_disconnect(struct usb_interface *interface);
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 19)
+static void mceusb_write_bulk_callback(struct urb *urb, struct pt_regs *regs);
 #else
-static void * mceusb_probe	(struct usb_device *dev, unsigned int ifnum, const struct usb_device_id *id);
-static void mceusb_disconnect	(struct usb_device *dev, void *ptr);
-static void mceusb_write_bulk_callback	(struct urb *urb);
+static void mceusb_write_bulk_callback(struct urb *urb);
+#endif
+#else
+static void *mceusb_probe(struct usb_device *dev, unsigned int ifnum,
+			  const struct usb_device_id *id);
+static void mceusb_disconnect(struct usb_device *dev, void *ptr);
+static void mceusb_write_bulk_callback(struct urb *urb);
 #endif
 
 /* read data from the usb bus; convert to mode2 */
-static int msir_fetch_more_data( struct usb_skel* dev, int dont_block );
+static int msir_fetch_more_data(struct usb_skel *dev, int dont_block);
 
 /* helper functions */
-static void msir_cleanup( struct usb_skel* dev );
-static void set_use_dec( void* data );
-static int set_use_inc( void* data );
-    
+static void msir_cleanup(struct usb_skel *dev);
+static void set_use_dec(void *data);
+static int set_use_inc(void *data);
+
 /* array of pointers to our devices that are currently connected */
-static struct usb_skel		*minor_table[MAX_DEVICES];
+static struct usb_skel *minor_table[MAX_DEVICES];
 
 /* lock to protect the minor_table structure */
-static DECLARE_MUTEX (minor_table_mutex);
-static void mceusb_setup( struct usb_device *udev );
+static DECLARE_MUTEX(minor_table_mutex);
+static void mceusb_setup(struct usb_device *udev);
 
 /* usb specific object needed to register this driver with the usb subsystem */
 static struct usb_driver mceusb_driver = {
-	.owner =	THIS_MODULE,
-	.name =		DRIVER_NAME,
-	.probe =	mceusb_probe,
-	.disconnect =	mceusb_disconnect,
-	.id_table =	mceusb_table,
+	LIRC_THIS_MODULE(.owner = THIS_MODULE)
+	.name		= DRIVER_NAME,
+	.probe		= mceusb_probe,
+	.disconnect	= mceusb_disconnect,
+	.id_table	= mceusb_table,
 };
 
 
 /**
  *	usb_mceusb_debug_data
  */
-static inline void usb_mceusb_debug_data (const char *function, int size,
+static inline void usb_mceusb_debug_data(const char *function, int size,
 					  const unsigned char *data)
 {
 	int i;
 	if (!debug)
 		return;
-	
-	printk(KERN_DEBUG __FILE__": %s - length = %d, data = ", 
+
+	printk(KERN_DEBUG __FILE__": %s - length = %d, data = ",
 	       function, size);
-	for (i = 0; i < size; ++i) {
+	for (i = 0; i < size; ++i)
 		printk(KERN_DEBUG "%.2x ", data[i]);
-	}
 	printk(KERN_DEBUG "\n");
 }
 
 /**
  *mceusb_delete
  */
-static inline void mceusb_delete (struct usb_skel *dev)
+static inline void mceusb_delete(struct usb_skel *dev)
 {
 	dprintk("%s", __func__);
 	minor_table[dev->minor] = NULL;
 #ifdef KERNEL_2_5
-	usb_buffer_free(dev->udev, dev->bulk_in_size, dev->bulk_in_buffer, dev->dma_in);
-	usb_buffer_free(dev->udev, dev->bulk_out_size, dev->bulk_out_buffer, dev->dma_out);
+	usb_buffer_free(dev->udev, dev->bulk_in_size,
+			dev->bulk_in_buffer, dev->dma_in);
+	usb_buffer_free(dev->udev, dev->bulk_out_size,
+			dev->bulk_out_buffer, dev->dma_out);
 #else
 	if (dev->bulk_in_buffer != NULL)
-		kfree (dev->bulk_in_buffer);
+		kfree(dev->bulk_in_buffer);
 	if (dev->bulk_out_buffer != NULL)
-		kfree (dev->bulk_out_buffer);
+		kfree(dev->bulk_out_buffer);
 #endif
 	if (dev->write_urb != NULL)
-		usb_free_urb (dev->write_urb);
-	kfree (dev);
+		usb_free_urb(dev->write_urb);
+	kfree(dev);
 }
 
-static void mceusb_setup( struct usb_device *udev )
+static void mceusb_setup(struct usb_device *udev)
 {
 	char data[8];
 	int res;
-	
-	memset( data, 0, 8 );
+
+	memset(data, 0, 8);
 
 	/* Get Status */
 	res = usb_control_msg(udev, usb_rcvctrlpipe(udev, 0),
 			      USB_REQ_GET_STATUS, USB_DIR_IN,
 			      0, 0, data, 2, HZ * 3);
-    
+
 	/*    res = usb_get_status( udev, 0, 0, data ); */
 	dprintk("%s - res = %d status = 0x%x 0x%x", __func__,
 		res, data[0], data[1]);
-    
+
 	/* This is a strange one. They issue a set address to the device
 	 * on the receive control pipe and expect a certain value pair back
 	 */
-	memset( data, 0, 8 );
+	memset(data, 0, 8);
 
-	res = usb_control_msg( udev, usb_rcvctrlpipe(udev, 0),
-			       5, USB_TYPE_VENDOR, 0, 0,
-			       data, 2, HZ * 3 );
+	res = usb_control_msg(udev, usb_rcvctrlpipe(udev, 0),
+			      5, USB_TYPE_VENDOR, 0, 0,
+			      data, 2, HZ * 3);
 	dprintk("%s - res = %d, devnum = %d", __func__, res, udev->devnum);
 	dprintk("%s - data[0] = %d, data[1] = %d", __func__,
-		data[0], data[1] );
+		data[0], data[1]);
+
 
-    
 	/* set feature */
-	res = usb_control_msg( udev, usb_sndctrlpipe(udev, 0),
-			       USB_REQ_SET_FEATURE, USB_TYPE_VENDOR,
-			       0xc04e, 0x0000, NULL, 0, HZ * 3 );
-    
+	res = usb_control_msg(udev, usb_sndctrlpipe(udev, 0),
+			      USB_REQ_SET_FEATURE, USB_TYPE_VENDOR,
+			      0xc04e, 0x0000, NULL, 0, HZ * 3);
+
 	dprintk("%s - res = %d", __func__, res);
 
 	/* These two are sent by the windows driver, but stall for
@@ -312,42 +323,42 @@ static void mceusb_setup( struct usb_device *udev )
 	 */
 #if 0
 	/* this is some custom control message they send */
-	res = usb_control_msg( udev, usb_sndctrlpipe(udev, 0),
-			       0x04, USB_TYPE_VENDOR,
-			       0x0808, 0x0000, NULL, 0, HZ * 3 );
-    
+	res = usb_control_msg(udev, usb_sndctrlpipe(udev, 0),
+			      0x04, USB_TYPE_VENDOR,
+			      0x0808, 0x0000, NULL, 0, HZ * 3);
+
 	dprintk("%s - res = %d", __func__, res);
-    
+
 	/* this is another custom control message they send */
-	res = usb_control_msg( udev, usb_sndctrlpipe(udev, 0),
-			       0x02, USB_TYPE_VENDOR,
-			       0x0000, 0x0100, NULL, 0, HZ * 3 );
-    
+	res = usb_control_msg(udev, usb_sndctrlpipe(udev, 0),
+			      0x02, USB_TYPE_VENDOR,
+			      0x0000, 0x0100, NULL, 0, HZ * 3);
+
 	dprintk("%s - res = %d", __func__, res);
 #endif
 }
 
-static void msir_cleanup( struct usb_skel* dev )
+static void msir_cleanup(struct usb_skel *dev)
 {
-	memset( dev->bulk_in_buffer, 0, dev->bulk_in_size );
+	memset(dev->bulk_in_buffer, 0, dev->bulk_in_size);
 
 	dev->usb_valid_bytes_in_bulk_buffer = 0;
 
 	dev->last_space = PULSE_MASK;
-    
+
 	dev->mce_bytes_left_in_packet = 0;
 	dev->lircidx = 0;
 	dev->lirccnt = 0;
-	memset( dev->lircdata, 0, sizeof(dev->lircdata) );
+	memset(dev->lircdata, 0, sizeof(dev->lircdata));
 }
 
-static int set_use_inc(void* data)
+static int set_use_inc(void *data)
 {
 	MOD_INC_USE_COUNT;
 	return 0;
 }
 
-static void set_use_dec(void* data)
+static void set_use_dec(void *data)
 {
 	MOD_DEC_USE_COUNT;
 }
@@ -368,108 +379,87 @@ static void set_use_dec(void* data)
  * This routine always returns the number of words available
  *
  */
-static int msir_fetch_more_data( struct usb_skel* dev, int dont_block )
+static int msir_fetch_more_data(struct usb_skel *dev, int dont_block)
 {
 	int retries = 0;
-	int words_to_read = 
+	int words_to_read =
 		(sizeof(dev->lircdata)/sizeof(lirc_t)) - dev->lirccnt;
 	int partial, this_read = 0;
 	int bulkidx = 0;
 	int bytes_left_in_packet = 0;
-	signed char* signedp = (signed char*)dev->bulk_in_buffer;
-	
-	if( words_to_read == 0 )
+	signed char *signedp = (signed char*)dev->bulk_in_buffer;
+
+	if (words_to_read == 0)
 		return dev->lirccnt;
 
 	/* this forces all existing data to be read by lirc before we
 	 * issue another usb command. this is the only form of
 	 * throttling we have
 	 */
-	if( dev->lirccnt )
-	{
+	if (dev->lirccnt)
 		return dev->lirccnt;
-	}
 
 	/* reserve room for our leading space */
-	if( dev->last_space )
+	if (dev->last_space)
 		words_to_read--;
-		
-	while( words_to_read )
-	{
+
+	while (words_to_read) {
 		/* handle signals and USB disconnects */
-		if( signal_pending(current) )
-		{
+		if (signal_pending(current))
 			return dev->lirccnt ? dev->lirccnt : -EINTR;
-		}
-		if( !dev->udev )
-		{
+		if (!dev->udev)
 			return -ENODEV;
-		}
 
 		bulkidx = 0;
 
 		/*
 		 * perform data read (phys or from previous buffer)
 		 */
-        
+
 		/* use leftovers if present, otherwise perform a read */
-		if( dev->usb_valid_bytes_in_bulk_buffer )
-		{
-			this_read = partial = 
-				dev->usb_valid_bytes_in_bulk_buffer;
+		if (dev->usb_valid_bytes_in_bulk_buffer) {
+			this_read = dev->usb_valid_bytes_in_bulk_buffer;
+			partial = this_read;
 			dev->usb_valid_bytes_in_bulk_buffer = 0;
-		}
-		else
-		{
+		} else {
 			int retval;
-            
+
 			this_read = dev->bulk_in_size;
 			partial = 0;
-			retval = usb_bulk_msg
-				(dev->udev,
-				 usb_rcvbulkpipe
-				 (dev->udev, dev->bulk_in_endpointAddr),
-				 (unsigned char*)dev->bulk_in_buffer,
-				 this_read, &partial, HZ*10);
-			
+			retval = usb_bulk_msg(dev->udev,
+					usb_rcvbulkpipe(dev->udev,
+						dev->bulk_in_endpointAddr),
+					(unsigned char *)dev->bulk_in_buffer,
+					this_read, &partial, HZ*10);
+
 			/* retry a few times on overruns; map all
 			   other errors to -EIO */
-			if( retval )
-			{
-				if( retval == -EOVERFLOW && 
-				    retries < 5 )
-				{
+			if (retval) {
+				if (retval == -EOVERFLOW && retries < 5) {
 					retries++;
-					interruptible_sleep_on_timeout
-						( &dev->wait_q, HZ );
+					interruptible_sleep_on_timeout(
+						&dev->wait_q, HZ);
 					continue;
-				}
-				else
-				{
+				} else
 					return -EIO;
-				}
 			}
-            
+
 			retries = 0;
-			if( partial )
+			if (partial)
 				this_read = partial;
 
 			/* skip the header */
 			bulkidx += 2;
-            
+
 			/* check for empty reads (header only) */
-			if( this_read == 2 )
-			{
+			if (this_read == 2) {
 				/* assume no data */
-				if( dont_block )
-				{
+				if (dont_block)
 					break;
-				}
 
 				/* sleep for a bit before performing
 				   another read */
-				interruptible_sleep_on_timeout
-					( &dev->wait_q, 1 );
+				interruptible_sleep_on_timeout(&dev->wait_q, 1);
 				continue;
 			}
 		}
@@ -477,19 +467,16 @@ static int msir_fetch_more_data( struct usb_skel* dev, int dont_block )
 		/*
 		 * process data
 		 */
-        
+
 		/* at this point this_read is > 0 */
-		while( bulkidx < this_read &&
-		       (words_to_read > (dev->last_space ? 1 : 0)) )
-			//while( bulkidx < this_read && words_to_read )
-		{
+		while (bulkidx < this_read &&
+		       (words_to_read > (dev->last_space ? 1 : 0))) {
+			/* while( bulkidx < this_read && words_to_read) */
 			int keycode;
 			int pulse = 0;
-            
+
 			/* read packet length if needed */
-			if( !bytes_left_in_packet )
-			{
-				
+			if (!bytes_left_in_packet) {
 				/* we assume we are on a packet length
 				 * value. it is possible, in some
 				 * cases, to get a packet that does
@@ -498,7 +485,7 @@ static int msir_fetch_more_data( struct usb_skel* dev, int dont_block )
 				 * but occaisonally we do not receive
 				 * the second half of a fragment
 				 */
-				bytes_left_in_packet = 
+				bytes_left_in_packet =
 					128 + signedp[bulkidx++];
 
 				/* unfortunately rather than keep all
@@ -513,11 +500,10 @@ static int msir_fetch_more_data( struct usb_skel* dev, int dont_block )
 				 * up, and 2) the bytes_left value for
 				 * this packet is obviously wrong
 				 */
-				if( bytes_left_in_packet > 4  )
-				{
-					if( dev->mce_bytes_left_in_packet )
-					{
-						bytes_left_in_packet = dev->mce_bytes_left_in_packet;
+				if (bytes_left_in_packet > 4) {
+					if (dev->mce_bytes_left_in_packet) {
+						bytes_left_in_packet =
+						  dev->mce_bytes_left_in_packet;
 						bulkidx--;
 					}
 					bytes_left_in_packet = 0;
@@ -527,31 +513,28 @@ static int msir_fetch_more_data( struct usb_skel* dev, int dont_block )
 				/* always clear this if we have a
 				   valid packet */
 				dev->mce_bytes_left_in_packet = 0;
-                    
+
 				/* continue here to verify we haven't
 				   hit the end of the bulk_in */
 				continue;
-				
+
 			}
 
 			/*
 			 * generate mode2
 			 */
-            
+
 			keycode = signedp[bulkidx++];
-			if( keycode < 0 )
-			{
+			if (keycode < 0) {
 				pulse = 1;
 				keycode += 128;
 			}
 			keycode *= MCE_TIME_UNIT;
 
 			bytes_left_in_packet--;
-            
-			if( pulse )
-			{
-				if( dev->last_space )
-				{
+
+			if (pulse) {
+				if (dev->last_space) {
 					dev->lircdata[dev->lirccnt++] =
 						dev->last_space;
 					dev->last_space = 0;
@@ -562,34 +545,28 @@ static int msir_fetch_more_data( struct usb_skel* dev, int dont_block )
 				}
 				dev->lircdata[dev->lirccnt] += keycode;
 				dev->lircdata[dev->lirccnt] |= PULSE_BIT;
-			}
-			else
-			{
+			} else {
 				/* on pulse->space transition, add one
 				   for the existing pulse */
-				if( dev->lircdata[dev->lirccnt] &&
-				    !dev->last_space )
-				{
+				if (dev->lircdata[dev->lirccnt] &&
+				    !dev->last_space) {
 					dev->lirccnt++;
 					words_to_read--;
 				}
-                
+
 				dev->last_space += keycode;
 			}
 		}
 	}
-	
+
 	/* save off some info if we are exiting mid-packet, or with
 	   leftovers */
-	if( bytes_left_in_packet )
-	{
+	if (bytes_left_in_packet)
 		dev->mce_bytes_left_in_packet = bytes_left_in_packet;
-	}
-	if( bulkidx < this_read )
-	{
+	if (bulkidx < this_read) {
 		dev->usb_valid_bytes_in_bulk_buffer = (this_read - bulkidx);
-		memcpy( dev->bulk_in_buffer, &(dev->bulk_in_buffer[bulkidx]),
-			dev->usb_valid_bytes_in_bulk_buffer );
+		memcpy(dev->bulk_in_buffer, &(dev->bulk_in_buffer[bulkidx]),
+		       dev->usb_valid_bytes_in_bulk_buffer);
 	}
 	return dev->lirccnt;
 }
@@ -600,71 +577,68 @@ static int msir_fetch_more_data( struct usb_skel* dev, int dont_block )
  * check for new data returns 0 on success, or -ENODATA if nothing is
  * available
  */
-static int mceusb_add_to_buf(void* data, struct lirc_buffer* buf )
+static int mceusb_add_to_buf(void *data, struct lirc_buffer *buf)
 {
-	struct usb_skel* dev = (struct usb_skel*) data;
+	struct usb_skel *dev = (struct usb_skel *) data;
 
-	down( &dev->sem );
+	down(&dev->sem);
 
 	/* verify device still present */
-	if( dev->udev == NULL )
-	{
-		up( &dev->sem );
+	if (dev->udev == NULL) {
+		up(&dev->sem);
 		return -ENODEV;
 	}
 
-	if( !dev->lirccnt )
-	{
+	if (!dev->lirccnt) {
 		int res;
 		dev->lircidx = 0;
-        
-		res = msir_fetch_more_data( dev, 1 );
-		
-		if( res == 0 )
+
+		res = msir_fetch_more_data(dev, 1);
+
+		if (res == 0)
 			res = -ENODATA;
-		if( res < 0 ) {
-			up( &dev->sem );
+		if (res < 0) {
+			up(&dev->sem);
 			return res;
 		}
 	}
 
-	if( dev->lirccnt )
-	{
+	if (dev->lirccnt) {
 		int keys_to_copy;
 
 		/* determine available buffer space and available data */
-		keys_to_copy = lirc_buffer_available( buf );
-		if( keys_to_copy > dev->lirccnt )
-		{
+		keys_to_copy = lirc_buffer_available(buf);
+		if (keys_to_copy > dev->lirccnt)
 			keys_to_copy = dev->lirccnt;
-		}
-        
-		lirc_buffer_write_n( buf, (unsigned char*) &(dev->lircdata[dev->lircidx]), keys_to_copy );
+
+		lirc_buffer_write_n(buf,
+			(unsigned char *) &(dev->lircdata[dev->lircidx]),
+			keys_to_copy);
 		dev->lircidx += keys_to_copy;
 		dev->lirccnt -= keys_to_copy;
-        
-		up( &dev->sem );
+
+		up(&dev->sem);
 		return 0;
 	}
 
-	up( &dev->sem );
+	up(&dev->sem);
 	return -ENODATA;
 }
 
 /**
  *	mceusb_write_bulk_callback
  */
-#ifdef KERNEL_2_5 
-static void mceusb_write_bulk_callback (struct urb *urb, struct pt_regs *regs)
+#if defined(KERNEL_2_5) && LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 19)
+static void mceusb_write_bulk_callback(struct urb *urb, struct pt_regs *regs)
 #else
-static void mceusb_write_bulk_callback (struct urb *urb)
+static void mceusb_write_bulk_callback(struct urb *urb)
 #endif
 {
 	struct usb_skel *dev = (struct usb_skel *)urb->context;
 
 	dprintk("%s - minor %d", __func__, dev->minor);
 
-	if ((urb->status != -ENOENT) && 
+	if ((urb->status != -ENOENT) &&
 	    (urb->status != -ECONNRESET)) {
 		dprintk("%s - nonzero write buld status received: %d",
 			__func__, urb->status);
@@ -677,36 +651,39 @@ static void mceusb_write_bulk_callback (struct urb *urb)
 /**
  *	mceusb_probe
  *
- *	Called by the usb core when a new device is connected that it 
+ *	Called by the usb core when a new device is connected that it
  *	thinks this driver might be interested in.
  */
-#ifdef KERNEL_2_5 
-static int mceusb_probe(struct usb_interface *interface, const struct usb_device_id *id)
+#ifdef KERNEL_2_5
+static int mceusb_probe(struct usb_interface *interface,
+			const struct usb_device_id *id)
 {
 	struct usb_device *udev = interface_to_usbdev(interface);
 	struct usb_host_interface *iface_desc;
 #else
-static void * mceusb_probe(struct usb_device *udev, unsigned int ifnum,
-			   const struct usb_device_id *id)
+static void *mceusb_probe(struct usb_device *udev, unsigned int ifnum,
+			  const struct usb_device_id *id)
 {
 	struct usb_interface *interface = &udev->actconfig->interface[ifnum];
-	struct usb_interface_descriptor *iface_desc;	
+	struct usb_interface_descriptor *iface_desc;
 #endif
 	struct usb_skel *dev = NULL;
 	struct usb_endpoint_descriptor *endpoint;
-	
-	struct lirc_plugin* plugin;
-	struct lirc_buffer* rbuf;
+
+	struct lirc_plugin *plugin;
+	struct lirc_buffer *rbuf;
 
 	int minor;
 	size_t buffer_size;
 	int i;
 	int retval = -ENOMEM;
-	
+	char junk[64];
+	int partial = 0;
+
 	/* See if the device offered us matches what we can accept */
-	if ((udev->descriptor.idVendor != USB_MCEUSB_VENDOR_ID) ||
-	    (udev->descriptor.idProduct != USB_MCEUSB_PRODUCT_ID)) {
-	    	dprintk("Wrong Vendor/Product IDs");
+	if (cpu_to_le16(udev->descriptor.idVendor) != USB_MCEUSB_VENDOR_ID ||
+	    cpu_to_le16(udev->descriptor.idProduct) != USB_MCEUSB_PRODUCT_ID) {
+		dprintk("Wrong Vendor/Product IDs");
 #ifdef KERNEL_2_5
 		return -ENODEV;
 #else
@@ -715,30 +692,30 @@ static void * mceusb_probe(struct usb_device *udev, unsigned int ifnum,
 	}
 
 	/* select a "subminor" number (part of a minor number) */
-	down (&minor_table_mutex);
+	down(&minor_table_mutex);
 	for (minor = 0; minor < MAX_DEVICES; ++minor) {
 		if (minor_table[minor] == NULL)
 			break;
 	}
 	if (minor >= MAX_DEVICES) {
-		info ("Too many devices plugged in, "
-		      "can not handle this device.");
+		info("Too many devices plugged in, "
+		     "can not handle this device.");
 		goto error;
 	}
 
 	/* allocate memory for our device state and initialize it */
-	dev = kmalloc (sizeof(struct usb_skel), GFP_KERNEL);
+	dev = kmalloc(sizeof(struct usb_skel), GFP_KERNEL);
 	if (dev == NULL) {
-		err ("Out of memory");
+		err("Out of memory");
 #ifdef KERNEL_2_5
 		retval = -ENOMEM;
 #endif
 		goto error;
 	}
 	minor_table[minor] = dev;
-	
-	memset (dev, 0x00, sizeof (*dev));
-	init_MUTEX (&dev->sem);
+
+	memset(dev, 0x00, sizeof(*dev));
+	init_MUTEX(&dev->sem);
 	dev->udev = udev;
 	dev->interface = interface;
 	dev->minor = minor;
@@ -746,10 +723,10 @@ static void * mceusb_probe(struct usb_device *udev, unsigned int ifnum,
 	/* set up the endpoint information */
 	/* check out the endpoints */
 	/* use only the first bulk-in and bulk-out endpoints */
-#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,4)
-	iface_desc = interface->cur_altsetting;
-#else
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 5)
 	iface_desc = &interface->altsetting[0];
+#else
+	iface_desc = interface->cur_altsetting;
 #endif
 
 #ifdef KERNEL_2_5
@@ -767,8 +744,9 @@ static void * mceusb_probe(struct usb_device *udev, unsigned int ifnum,
 			dev->bulk_in_size = buffer_size;
 			dev->bulk_in_endpointAddr = endpoint->bEndpointAddress;
 #ifdef KERNEL_2_5
-			dev->bulk_in_buffer = usb_buffer_alloc
-				(udev, buffer_size, SLAB_ATOMIC, &dev->dma_in);
+			dev->bulk_in_buffer =
+				usb_buffer_alloc(udev, buffer_size,
+						 GFP_ATOMIC, &dev->dma_in);
 #else
 			dev->bulk_in_buffer = kmalloc(buffer_size, GFP_KERNEL);
 #endif
@@ -777,10 +755,11 @@ static void * mceusb_probe(struct usb_device *udev, unsigned int ifnum,
 				goto error;
 			}
 		}
-		
-		if (((endpoint->bEndpointAddress & USB_ENDPOINT_DIR_MASK) == 0x00) &&
-		    ((endpoint->bmAttributes & USB_ENDPOINT_XFERTYPE_MASK) ==
-		     USB_ENDPOINT_XFER_BULK)) {
+
+		if (((endpoint->bEndpointAddress & USB_ENDPOINT_DIR_MASK)
+		    == 0x00)
+		    && ((endpoint->bmAttributes & USB_ENDPOINT_XFERTYPE_MASK) ==
+		    USB_ENDPOINT_XFER_BULK)) {
 			dprintk("we found a bulk out endpoint");
 #ifdef KERNEL_2_5
 			dev->write_urb = usb_alloc_urb(0, GFP_KERNEL);
@@ -795,27 +774,29 @@ static void * mceusb_probe(struct usb_device *udev, unsigned int ifnum,
 			dev->bulk_out_size = buffer_size;
 			dev->bulk_out_endpointAddr = endpoint->bEndpointAddress;
 #ifdef KERNEL_2_5
-			dev->bulk_out_buffer = usb_buffer_alloc(udev, buffer_size, SLAB_ATOMIC, &dev->dma_out);
+			dev->bulk_out_buffer =
+				usb_buffer_alloc(udev, buffer_size,
+						 GFP_ATOMIC, &dev->dma_out);
 #else
-			dev->bulk_out_buffer = kmalloc (buffer_size, GFP_KERNEL);
+			dev->bulk_out_buffer = kmalloc(buffer_size, GFP_KERNEL);
 #endif
 			if (!dev->bulk_out_buffer) {
 				err("Couldn't allocate bulk_out_buffer");
 				goto error;
 			}
 #ifdef KERNEL_2_5
-			usb_fill_bulk_urb(dev->write_urb, udev, 
+			usb_fill_bulk_urb(dev->write_urb, udev,
 				      usb_sndbulkpipe
 				      (udev, endpoint->bEndpointAddress),
 				      dev->bulk_out_buffer, buffer_size,
 				      mceusb_write_bulk_callback, dev);
 #else
 			FILL_BULK_URB(dev->write_urb, udev,
-				      usb_sndbulkpipe
-				      (udev, endpoint->bEndpointAddress),
+				      usb_sndbulkpipe(udev,
+						endpoint->bEndpointAddress),
 				      dev->bulk_out_buffer, buffer_size,
 				      mceusb_write_bulk_callback, dev);
-#endif 
+#endif
 		}
 	}
 
@@ -825,89 +806,87 @@ static void * mceusb_probe(struct usb_device *udev, unsigned int ifnum,
 	}
 
 	/* init the waitq */
-	init_waitqueue_head( &dev->wait_q );
+	init_waitqueue_head(&dev->wait_q);
 
 
 	/* Set up our lirc plugin */
-	if(!(plugin = kmalloc(sizeof(struct lirc_plugin), GFP_KERNEL))) {
+	plugin = kmalloc(sizeof(struct lirc_plugin), GFP_KERNEL);
+	if (!plugin) {
 		err("out of memory");
 		goto error;
 	}
-	memset( plugin, 0, sizeof(struct lirc_plugin) );
+	memset(plugin, 0, sizeof(struct lirc_plugin));
 
-	if(!(rbuf = kmalloc(sizeof(struct lirc_buffer), GFP_KERNEL))) {
+	rbuf = kmalloc(sizeof(struct lirc_buffer), GFP_KERNEL);
+	if (!rbuf) {
 		err("out of memory");
-		kfree( plugin );
+		kfree(plugin);
 		goto error;
 	}
-    
+
 	/* the lirc_atiusb module doesn't memset rbuf here ... ? */
-	if( lirc_buffer_init( rbuf, sizeof(lirc_t), 128)) {
+	if (lirc_buffer_init(rbuf, sizeof(lirc_t), 128)) {
 		err("out of memory");
-		kfree( plugin );
-		kfree( rbuf );
+		kfree(plugin);
+		kfree(rbuf);
 		goto error;
 	}
 
 	strcpy(plugin->name, DRIVER_NAME " ");
-	plugin->minor       = minor;
+	plugin->minor = minor;
 	plugin->code_length = sizeof(lirc_t) * 8;
-	plugin->features    = LIRC_CAN_REC_MODE2; // | LIRC_CAN_SEND_MODE2;
-	plugin->data        = dev;
-	plugin->rbuf        = rbuf;
-	plugin->ioctl       = NULL;
+	plugin->features = LIRC_CAN_REC_MODE2; /* | LIRC_CAN_SEND_MODE2; */
+	plugin->data = dev;
+	plugin->rbuf = rbuf;
+	plugin->ioctl = NULL;
 	plugin->set_use_inc = &set_use_inc;
 	plugin->set_use_dec = &set_use_dec;
-	plugin->sample_rate = 80;   // sample at 100hz (10ms)
-	plugin->add_to_buf  = &mceusb_add_to_buf;
-	//    plugin->fops        = &mceusb_fops;
-	plugin->owner       = THIS_MODULE;
-	if( lirc_register_plugin(plugin) < 0 )
-	{
-		kfree( plugin );
-		lirc_buffer_free( rbuf );
-		kfree( rbuf );
+	plugin->sample_rate = 80;   /* sample at 100hz (10ms) */
+	plugin->add_to_buf = &mceusb_add_to_buf;
+	/* plugin->fops = &mceusb_fops; */
+#ifdef LIRC_HAVE_SYSFS
+	plugin->dev = &udev->dev;
+#endif
+	plugin->owner = THIS_MODULE;
+	if (lirc_register_plugin(plugin) < 0) {
+		kfree(plugin);
+		lirc_buffer_free(rbuf);
+		kfree(rbuf);
 		goto error;
 	}
 	dev->plugin = plugin;
-	
+
 	/* clear off the first few messages. these look like
 	 * calibration or test data, i can't really tell
 	 * this also flushes in case we have random ir data queued up
 	 */
-	{
-		char junk[64];
-		int partial = 0, retval, i;
-		for( i = 0; i < 40; i++ )
-		{
-			retval = usb_bulk_msg
-				(udev, usb_rcvbulkpipe
-				 (udev, dev->bulk_in_endpointAddr),
-				 junk, 64,
-				 &partial, HZ*10);
-		}
-	}
-    
-	msir_cleanup( dev );
-	mceusb_setup( udev );
-	
+	for (i = 0; i < 40; i++)
+		(void) usb_bulk_msg(udev,
+				    usb_rcvbulkpipe(udev,
+						    dev->bulk_in_endpointAddr),
+				    junk, 64, &partial, HZ*10);
+
+	msir_cleanup(dev);
+	mceusb_setup(udev);
+
 #ifdef KERNEL_2_5
 	/* we can register the device now, as it is ready */
-	usb_set_intfdata (interface, dev);
-#endif	
+	usb_set_intfdata(interface, dev);
+#endif
 	/* let the user know what node this device is now attached to */
-	//info ("USB Microsoft IR Transceiver device now attached to msir%d", dev->minor);
-	up (&minor_table_mutex);
+	/* info("USB Microsoft IR Transceiver device now attached to msir%d",
+		dev->minor); */
+	up(&minor_table_mutex);
 #ifdef KERNEL_2_5
 	return 0;
 #else
 	return dev;
 #endif
- error:
-	mceusb_delete (dev);
+error:
+	mceusb_delete(dev);
 	dev = NULL;
 	dprintk("%s: retval = %x", __func__, retval);
-	up (&minor_table_mutex);
+	up(&minor_table_mutex);
 #ifdef KERNEL_2_5
 	return retval;
 #else
@@ -926,7 +905,7 @@ static void * mceusb_probe(struct usb_device *udev, unsigned int ifnum,
  *	not provide any way to do this.  But at least we can cancel an active
  *	write.
  */
-#ifdef KERNEL_2_5 
+#ifdef KERNEL_2_5
 static void mceusb_disconnect(struct usb_interface *interface)
 #else
 static void mceusb_disconnect(struct usb_device *udev, void *ptr)
@@ -935,37 +914,37 @@ static void mceusb_disconnect(struct usb_device *udev, void *ptr)
 	struct usb_skel *dev;
 	int minor;
 #ifdef KERNEL_2_5
-	dev = usb_get_intfdata (interface);
-	usb_set_intfdata (interface, NULL);
+	dev = usb_get_intfdata(interface);
+	usb_set_intfdata(interface, NULL);
 #else
 	dev = (struct usb_skel *)ptr;
 #endif
-	
-	down (&minor_table_mutex);
-	down (&dev->sem);
+
+	down(&minor_table_mutex);
+	down(&dev->sem);
 	minor = dev->minor;
 
 	/* unhook lirc things */
-	lirc_unregister_plugin( minor );
-	lirc_buffer_free( dev->plugin->rbuf );
-	kfree( dev->plugin->rbuf );
-	kfree( dev->plugin );
+	lirc_unregister_plugin(minor);
+	lirc_buffer_free(dev->plugin->rbuf);
+	kfree(dev->plugin->rbuf);
+	kfree(dev->plugin);
 #ifdef KERNEL_2_5
 	/* terminate an ongoing write */
-	if (atomic_read (&dev->write_busy)) {
-		usb_kill_urb (dev->write_urb);
-		wait_for_completion (&dev->write_finished);
+	if (atomic_read(&dev->write_busy)) {
+		usb_kill_urb(dev->write_urb);
+		wait_for_completion(&dev->write_finished);
 	}
 
 	/* prevent device read, write and ioctl */
 	dev->present = 0;
 #endif
-	
-	mceusb_delete (dev);
-	
+
+	mceusb_delete(dev);
+
 	info("Microsoft IR Transceiver #%d now disconnected", minor);
-	up (&dev->sem);
-	up (&minor_table_mutex);
+	up(&dev->sem);
+	up(&minor_table_mutex);
 }
 
 
@@ -979,12 +958,13 @@ static int __init usb_mceusb_init(void)
 
 	/* register this driver with the USB subsystem */
 	result = usb_register(&mceusb_driver);
-#ifdef KERNEL_2_5	
-	if ( result ) {
+#ifdef KERNEL_2_5
+	if (result) {
 #else
-	if ( result < 0 ) {
+	if (result < 0) {
 #endif
-		err("usb_register failed for the " DRIVER_NAME " driver. error number %d",result);
+		err("usb_register failed for the " DRIVER_NAME
+		    " driver. error number %d", result);
 #ifdef KERNEL_2_5
 		return result;
 #else
@@ -1006,13 +986,13 @@ static void __exit usb_mceusb_exit(void)
 	usb_deregister(&mceusb_driver);
 }
 
- module_init (usb_mceusb_init);
-module_exit (usb_mceusb_exit);
+module_init(usb_mceusb_init);
+module_exit(usb_mceusb_exit);
 
 MODULE_DESCRIPTION(DRIVER_DESC);
 MODULE_AUTHOR(DRIVER_AUTHOR);
 MODULE_LICENSE("GPL");
-MODULE_DEVICE_TABLE (usb, mceusb_table);
+MODULE_DEVICE_TABLE(usb, mceusb_table);
 
 module_param(debug, int, 0644);
 MODULE_PARM_DESC(debug, "Debug enabled or not");
