@@ -1,4 +1,4 @@
-/*      $Id: lirc_client.c,v 5.23 2006/01/08 18:32:58 lirc Exp $      */
+/*      $Id: lirc_client.c,v 5.26 2007/03/24 12:54:43 lirc Exp $      */
 
 /****************************************************************************
  ** lirc_client.c ***********************************************************
@@ -1266,6 +1266,8 @@ static int lirc_readconfig_only_internal(char *file,
 	}
 	if(ret==0)
 	{
+		char *startupmode;
+		
 		*config=(struct lirc_config *)
 			malloc(sizeof(struct lirc_config));
 		if(*config==NULL)
@@ -1276,7 +1278,8 @@ static int lirc_readconfig_only_internal(char *file,
 		}
 		(*config)->first=first;
 		(*config)->next=first;
-		(*config)->current_mode=lirc_startupmode((*config)->first);
+		startupmode = lirc_startupmode((*config)->first);
+		(*config)->current_mode=startupmode ? strdup(startupmode):NULL;
 		(*config)->sockfd=-1;
 		if(full_name != NULL)
 		{
@@ -1368,6 +1371,7 @@ void lirc_freeconfig(struct lirc_config *config)
 			config->sockfd=-1;
 		}
 		lirc_freeconfigentries(config->first);
+		free(config->current_mode);
 		free(config);
 	}
 }
@@ -1431,6 +1435,7 @@ static void lirc_clearmode(struct lirc_config *config)
 		}
 		scan=scan->next;
 	}
+	free(config->current_mode);
 	config->current_mode=NULL;
 }
 
@@ -1446,7 +1451,8 @@ static char *lirc_execute(struct lirc_config *config,
 	}
 	if(scan->change_mode!=NULL)
 	{
-		config->current_mode=scan->change_mode;
+		free(config->current_mode);
+		config->current_mode=strdup(scan->change_mode);
 		if(scan->flags&once)
 		{
 			if(scan->flags&ecno)
@@ -1807,6 +1813,44 @@ const char *lirc_getmode(struct lirc_config *config)
 	return config->current_mode;
 }
 
+const char *lirc_setmode(struct lirc_config *config, const char *mode)
+{
+	if(config->sockfd!=-1)
+	{
+		static char buf[LIRC_PACKET_SIZE];
+		size_t buf_len = LIRC_PACKET_SIZE;
+		int success;
+		int ret;
+		char cmd[LIRC_PACKET_SIZE];
+		if(snprintf(cmd, LIRC_PACKET_SIZE, "SETMODE%s%s\n",
+			    mode ? " ":"",
+			    mode ? mode:"")
+		   >= LIRC_PACKET_SIZE)
+		{
+			return NULL;
+		}
+		
+		ret = lirc_send_command(config->sockfd, cmd,
+					buf, &buf_len, &success);
+		if(success == LIRC_RET_SUCCESS)
+		{
+			if(ret > 0)
+			{
+				return buf;
+			}
+			else
+			{
+				return NULL;
+			}
+		}
+		return NULL;
+	}
+	
+	free(config->current_mode);
+	config->current_mode = mode ? strdup(mode) : NULL;
+	return config->current_mode;
+}
+
 static const char *lirc_read_string(int fd)
 {
 	static char buffer[LIRC_PACKET_SIZE+1]="";
